@@ -25,13 +25,15 @@
 
 	$page["file"]	= "history.php";
 	$page["title"]	= "S_HISTORY";
-
-	if(isset($_REQUEST['plaintext']) || isset($_REQUEST['fullscreen']))
-	{
+	$page['hist_arg'] = array('hostid','grouid','graphid','period','dec','inc','left','right','stime');
+	$page['scripts'] = array('gmenu.js','scrollbar.js','sbox.js','sbinit.js');
+	
+	$page['type'] = detect_page_type(PAGE_TYPE_HTML);
+		
+	if(isset($_REQUEST['plaintext'])){
 		define('ZBX_PAGE_NO_MENU', 1);
 	}
-	else
-	{
+	else if(PAGE_TYPE_HTML == $page['type']){
 		define('ZBX_PAGE_DO_REFRESH', 1);
 	}
 
@@ -41,10 +43,10 @@ include_once "include/page_header.php";
 <?php
 //		VAR			TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
 	$fields=array(
-		"itemid"=>	array(T_ZBX_INT, O_MAND, P_SYS,	DB_ID,	null),
+		"itemid"=>	array(T_ZBX_INT, O_OPT, P_SYS,	DB_ID,	'!isset({favobj})'),
 		
 		"from"=>	array(T_ZBX_INT, O_OPT,	 null,	'{}>=0', null),
-		"period"=>	array(T_ZBX_INT, O_OPT,	 null,	BETWEEN(ZBX_MIN_PERIOD,ZBX_MAX_PERIOD), null),
+		"period"=>	array(T_ZBX_INT, O_OPT,	 null,	null, null),
 		"dec"=>		array(T_ZBX_INT, O_OPT,	 null,	null, null),
 		"inc"=>		array(T_ZBX_INT, O_OPT,	 null,	null, null),
 		"left"=>	array(T_ZBX_INT, O_OPT,	 null,	null, null),
@@ -59,7 +61,10 @@ include_once "include/page_header.php";
 		"cmbloglist"=>	array(T_ZBX_INT, O_OPT,	 null,	DB_ID, null),
 
 		"plaintext"=>	array(T_ZBX_STR, O_OPT,	 null,	null, null),
-		"action"=>	array(T_ZBX_STR, O_OPT,	 null,	IN('"showgraph","showvalues","showlatest"'), null),
+		"action"=>	array(T_ZBX_STR, O_OPT,	 null,	IN('"showgraph","showvalues","showlatest","add","remove"'), null),
+//ajax
+		'favobj'=>		array(T_ZBX_STR, O_OPT, P_ACT,	NULL,			NULL),
+		'favid'=>		array(T_ZBX_STR, O_OPT, P_ACT,  NOT_EMPTY,		'isset({favobj})'),
 
 /* actions */
 		"remove_log"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
@@ -69,75 +74,115 @@ include_once "include/page_header.php";
 		"form"=>		array(T_ZBX_STR, O_OPT, P_SYS,	null,	null),
 		"form_copy_to"=>	array(T_ZBX_STR, O_OPT, P_SYS,	null,	null),
 		"form_refresh"=>	array(T_ZBX_INT, O_OPT,	null,	null,	null),
-		"fullscreen"=>		array(T_ZBX_STR, O_OPT,	P_SYS,	null,	null)
+		"fullscreen"=>		array(T_ZBX_INT, O_OPT,	P_SYS,	null,	null)
 	);
 
 	check_fields($fields);
 ?>
 <?php
+	if(isset($_REQUEST['favobj'])){
+		if(in_array($_REQUEST['favobj'],array('itemid','graphid'))){
+			$result = false;
+			if('add' == $_REQUEST['action']){
+				$result = add2favorites('web.favorite.graphids',$_REQUEST['favid'],$_REQUEST['favobj']);
+				if($result){
+					print('$("addrm_fav").title = "'.S_REMOVE_FROM.' '.S_FAVORITES.'";'."\n");
+					print('$("addrm_fav").onclick = function(){rm4favorites("itemid","'.$_REQUEST['favid'].'",0);}'."\n");
+				}
+			}
+			else if('remove' == $_REQUEST['action']){
+				$result = rm4favorites('web.favorite.graphids',$_REQUEST['favid'],ZBX_FAVORITES_ALL,$_REQUEST['favobj']);
+				
+				if($result){
+					print('$("addrm_fav").title = "'.S_ADD_TO.' '.S_FAVORITES.'";'."\n");
+					print('$("addrm_fav").onclick = function(){ add2favorites("itemid","'.$_REQUEST['favid'].'");}'."\n");
+				}
+			}
+
+			if((PAGE_TYPE_JS == $page['type']) && $result){
+				print('switchElementsClass("addrm_fav","iconminus","iconplus");');
+			}
+		}
+	}	
+	
+	if((PAGE_TYPE_JS == $page['type']) || (PAGE_TYPE_HTML_BLOCK == $page['type'])){
+		exit();
+	}
+
 	$_REQUEST["action"] = get_request("action", "showgraph");
 
 /*** Prepare page header - start ***/
-	if(is_array($_REQUEST["itemid"]))
-	{
-
+	if(is_array($_REQUEST["itemid"])){
 		$_REQUEST["itemid"] = array_unique($_REQUEST["itemid"]);
 
-		if(isset($_REQUEST["remove_log"]) && isset($_REQUEST["cmbloglist"]))
-		{
+		if(isset($_REQUEST["remove_log"]) && isset($_REQUEST["cmbloglist"])){
 			foreach($_REQUEST["itemid"] as $id => $itemid)
 				if((bccomp($itemid , $_REQUEST["cmbloglist"])==0))
 					unset($_REQUEST["itemid"][$id]);
 		}
 
 		$items_count = count($_REQUEST["itemid"]);
-		if($items_count > 1)
-		{
+		if($items_count > 1){
 			$main_header = count($_REQUEST["itemid"])." log files";
 		}
-		else
-		{
+		else{
 			$_REQUEST["itemid"] = array_pop($_REQUEST["itemid"]);
 		}
 	}
 
-	$denyed_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_MODE_LT);
-
-	$availiable_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,null,null,get_current_nodeid());
+	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
 	
-	if((DBfetch(DBselect("select h.host,i.hostid,i.description,i.key_ from items i,hosts h ".
-		" where i.itemid in (".(is_array($_REQUEST["itemid"]) ? implode(',', $_REQUEST["itemid"]) : $_REQUEST["itemid"]).") ".
-		" and h.hostid=i.hostid ".
-		" and h.hostid in (".$denyed_hosts.")"))))
-	{
+	$sql = 'SELECT h.host,i.hostid,i.description,i.key_ '.
+			' FROM items i,hosts h '.
+			' WHERE i.itemid IN ('.(is_array($_REQUEST["itemid"]) ? implode(',', $_REQUEST["itemid"]) : $_REQUEST["itemid"]).') '.
+				' AND h.hostid=i.hostid '.
+				' AND '.DBcondition('h.hostid',$available_hosts, true);
+				
+	if(DBfetch(DBselect($sql))){
 		access_deny();
 	}
 	
-	$item_data = DBfetch(DBselect("select h.host,i.hostid,i.* from items i,hosts h ".
-		" where i.itemid in (".(is_array($_REQUEST["itemid"]) ? implode(',', $_REQUEST["itemid"]) : $_REQUEST["itemid"]).") ".
-		" and h.hostid=i.hostid "));
+	$sql = 'SELECT h.host,i.hostid,i.* '.
+			' FROM items i,hosts h '.
+			' WHERE i.itemid in ('.(is_array($_REQUEST["itemid"]) ? implode(',', $_REQUEST["itemid"]) : $_REQUEST["itemid"]).') '.
+				' AND h.hostid=i.hostid ';
+	$item_data = DBfetch(DBselect($sql));
 
 	$item_type = $item_data["value_type"];
 	$l_header = null;
 
-	if(!is_array($_REQUEST["itemid"]))
-	{
-		$main_header = $item_data["host"].": ".item_description($item_data["description"],$item_data["key_"]);
+	if(!is_array($_REQUEST['itemid'])){
+		$main_header = $item_data['host'].': '.item_description($item_data);
 		
-		if(isset($_REQUEST["plaintext"]))
-			echo $main_header.BR;
+		if(isset($_REQUEST['plaintext']))
+			echo $main_header.SBR;
 	
-		if($_REQUEST["action"]=="showgraph")
-		{
-			$_REQUEST["period"] = get_request("period",get_profile("web.item[".$_REQUEST["itemid"]."].graph.period", ZBX_PERIOD_DEFAULT));
-			if($_REQUEST["period"] >= ZBX_MIN_PERIOD)
-			{
-				update_profile("web.item[".$_REQUEST["itemid"]."].graph.period",$_REQUEST["period"]);
+		$_REQUEST['period'] = get_request('period',get_profile('web.item.graph.period', ZBX_PERIOD_DEFAULT, PROFILE_TYPE_INT, $_REQUEST['itemid']));
+		if($_REQUEST['period'] >= ZBX_MIN_PERIOD){
+			update_profile('web.item.graph.period',$_REQUEST['period'], PROFILE_TYPE_INT, $_REQUEST['itemid']);
+		}
+
+		$l_header = array(new CLink($item_data['host'],'latest.php?hostid='.$item_data['hostid']),': ',
+			item_description($item_data));
+			
+		if('showgraph' == $_REQUEST['action']){
+			if(infavorites('web.favorite.graphids',$_REQUEST['itemid'],'itemid')){
+				$icon = new CDiv(SPACE,'iconminus');
+				$icon->AddOption('title',S_REMOVE_FROM.' '.S_FAVORITES);
+				$icon->AddAction('onclick',new CScript("javascript: rm4favorites('itemid','".$_REQUEST['itemid']."',0);"));
 			}
+			else{
+				$icon = new CDiv(SPACE,'iconplus');
+				$icon->AddOption('title',S_ADD_TO.' '.S_FAVORITES);
+				$icon->AddAction('onclick',new CScript("javascript: add2favorites('itemid','".$_REQUEST['itemid']."');"));
+			}
+			$icon->AddOption('id','addrm_fav');
+	
+			$icon_tab = new CTable();
+			$icon_tab->AddRow(array($icon,SPACE,$l_header));
+			
+			$l_header = $icon_tab;
 		}
-		
-		$l_header = array(new CLink($item_data['host'],"latest.php?hostid=".$item_data['hostid']),": ",
-			item_description($item_data["description"],$item_data["key_"]));
 	}
 
 	$effectiveperiod = navigation_bar_calc();
@@ -146,39 +191,33 @@ include_once "include/page_header.php";
 
 	$to_save_request = null;
 
-	if( !isset($_REQUEST['plaintext']) && !isset($_REQUEST['fullscreen']) )
-	{
-		if($item_type == ITEM_VALUE_TYPE_LOG)
-		{
+	if( !isset($_REQUEST['plaintext']) && ($_REQUEST['fullscreen']==0) ){
+		if($item_type == ITEM_VALUE_TYPE_LOG){
 			$l_header = new CForm();
-			$l_header->SetName("loglist");
-			$l_header->AddVar("action",$_REQUEST["action"]);
-			$l_header->AddVar("from",$_REQUEST["from"]);
-			$l_header->AddVar("period",$_REQUEST["period"]);
-			$l_header->AddVar("itemid",$_REQUEST["itemid"]);
+			$l_header->SetName('loglist');
+			$l_header->AddVar('action',$_REQUEST['action']);
+			$l_header->AddVar('from',$_REQUEST['from']);
+			$l_header->AddVar('period',$_REQUEST['period']);
+			$l_header->AddVar('itemid',$_REQUEST['itemid']);
 
-			if(isset($_REQUEST["filter_task"]))	$l_header->AddVar("filter_task",$_REQUEST["filter_task"]);
-			if(isset($_REQUEST["filter"]))		$l_header->AddVar("filter",$_REQUEST["filter"]);
-			if(isset($_REQUEST["mark_color"]))	$l_header->AddVar("mark_color",$_REQUEST["mark_color"]);
+			if(isset($_REQUEST['filter_task']))	$l_header->AddVar('filter_task',$_REQUEST['filter_task']);
+			if(isset($_REQUEST['filter']))		$l_header->AddVar('filter',$_REQUEST['filter']);
+			if(isset($_REQUEST['mark_color']))	$l_header->AddVar('mark_color',$_REQUEST['mark_color']);
 
-			$cmbLogList = new CComboBox("cmbloglist");
-			if(is_array($_REQUEST["itemid"]))
-			{
+			$cmbLogList = new CComboBox('cmbloglist');
+			if(is_array($_REQUEST['itemid'])){
 				$cmbLogList->AddItem(0, $main_header);
-				foreach($_REQUEST["itemid"] as $itemid)
-				{
-					if(!($item = get_item_by_itemid($itemid)) || $item["value_type"] != ITEM_VALUE_TYPE_LOG)
-					{
+				foreach($_REQUEST['itemid'] as $itemid){
+					if(!($item = get_item_by_itemid($itemid)) || $item['value_type'] != ITEM_VALUE_TYPE_LOG){
 						invalid_url();
 					}
 					
-					$host = get_host_by_hostid($item["hostid"]);
-					$cmbLogList->AddItem($itemid,$host["host"].": ".item_description($item["description"],$item["key_"]));
+					$host = get_host_by_hostid($item['hostid']);
+					$cmbLogList->AddItem($itemid,$host['host'].': '.item_description($item));
 				}
 			}
-			else
-			{
-				$cmbLogList->AddItem($_REQUEST["itemid"], $main_header);
+			else{
+				$cmbLogList->AddItem($_REQUEST['itemid'], $main_header);
 			}
 
 			$l_header->AddItem(array(
@@ -195,24 +234,17 @@ include_once "include/page_header.php";
 		
 		$form->AddVar("itemid",$_REQUEST["itemid"]);
 
-		if($_REQUEST["action"]!="showlatest")
-		{
-			$form->AddVar("from",$_REQUEST["from"]);
-			$form->AddVar("period",$_REQUEST["period"]);
-		}
-
 		if(isset($_REQUEST["filter_task"]))	$form->AddVar("filter_task",$_REQUEST["filter_task"]);
 		if(isset($_REQUEST["filter"]))		$form->AddVar("filter",$_REQUEST["filter"]);
 		if(isset($_REQUEST["mark_color"]))	$form->AddVar("mark_color",$_REQUEST["mark_color"]);
 		
 		$cmbAction = new CComboBox("action",$_REQUEST["action"],"submit()");
 
-		if(str_in_array($item_type,array(ITEM_VALUE_TYPE_FLOAT,ITEM_VALUE_TYPE_UINT64)))
-		{
-			$cmbAction->AddItem("showgraph",S_GRAPH_OF_SPECIFIED_PERIOD);
+		if(str_in_array($item_type,array(ITEM_VALUE_TYPE_FLOAT,ITEM_VALUE_TYPE_UINT64))){
+			$cmbAction->AddItem("showgraph",S_GRAPH);
 		}
 
-		$cmbAction->AddItem("showvalues",S_VALUES_OF_SPECIFIED_PERIOD);
+		$cmbAction->AddItem("showvalues",S_VALUES);
 		$cmbAction->AddItem("showlatest",S_500_LATEST_VALUES);
 
 		$form->AddItem($cmbAction);
@@ -224,30 +256,27 @@ include_once "include/page_header.php";
 	}
 ?>
 <?php
-	if($_REQUEST["action"]=="showgraph" && $item_type != ITEM_VALUE_TYPE_LOG)
-	{
-		show_history($_REQUEST["itemid"],$_REQUEST["from"],$_REQUEST["stime"],$effectiveperiod);
-	}
-	elseif($_REQUEST["action"]=="showvalues" || $_REQUEST["action"]=="showlatest")
-	{
-		if($_REQUEST["action"]=="showvalues")
-		{		
-			$time = time(null) - $effectiveperiod - $_REQUEST["from"] * 3600;
-			$till = time(null) - $_REQUEST["from"] * 3600;
-			$hours=$effectiveperiod / 3600;
+	if($_REQUEST["action"]=="showgraph" && $item_type != ITEM_VALUE_TYPE_LOG){
+		$dom_graph_id = 'graph';
 
-			$l_header = "Showing history of ".$effectiveperiod." seconds($hours h)".BR.
-				"[from: ".date("Y.M.d H:i:s",$time)."] [till: ".date("Y.M.d H:i:s",$till)."]";
+		$bstime = isset($_REQUEST['stime'])?$_REQUEST['stime']:date('YmdHi',(time()-$_REQUEST['period']));
+		show_history($_REQUEST["itemid"],$_REQUEST["from"],$bstime,$effectiveperiod);
+	}
+	else if($_REQUEST["action"]=="showvalues" || $_REQUEST["action"]=="showlatest"){
+		if($_REQUEST["action"]=="showvalues"){
+			
+			$bstime = isset($_REQUEST['stime'])?$_REQUEST['stime']:date('YmdHi',(time()-$_REQUEST['period']));
+			$time = mktime(substr($bstime,8,2),substr($bstime,10,2),0,substr($bstime,4,2),substr($bstime,6,2),substr($bstime,0,4));
+			$till = $time + $effectiveperiod;
+			
+			$l_header = array(S_SHOWING_HISTORY_OF.SPACE.zbx_date2age(0,$effectiveperiod),'['.S_FROM_SMALL.': '.date('Y.M.d H:i:s',$time).']');
 		}
-		else
-		{
+		else{
 			$l_header = null;
 		}
 
-		if(!isset($_REQUEST["plaintext"]))
-		{
-			if($item_type==ITEM_VALUE_TYPE_LOG)
-			{
+		if(!isset($_REQUEST["plaintext"])){
+			if($item_type==ITEM_VALUE_TYPE_LOG){
 				$to_save_request = array("filter_task", "filter", "mark_color");
 
 				$filter_task = get_request("filter_task",0);
@@ -269,12 +298,11 @@ include_once "include/page_header.php";
 				$cmbFTask->AddItem(FILTER_TAST_INVERT_MARK,S_MARK_OTHERS);
 
 				$r_header->AddItem(array(
-					"Select rows with value like",SPACE,
+					S_SELECT_ROWS_WITH_VALUE_LIKE,SPACE,
 					new CTextBox("filter",$filter,25),
 					$cmbFTask,SPACE));
 
-				if(str_in_array($filter_task,array(FILTER_TAST_MARK,FILTER_TAST_INVERT_MARK)))
-				{
+				if(str_in_array($filter_task,array(FILTER_TAST_MARK,FILTER_TAST_INVERT_MARK))){
 					$cmbColor = new CComboBox("mark_color",$mark_color);
 					$cmbColor->AddItem(MARK_COLOR_RED,S_AS_RED);
 					$cmbColor->AddItem(MARK_COLOR_GREEN,S_AS_GREEN);
@@ -283,81 +311,76 @@ include_once "include/page_header.php";
 				}
 				$r_header->AddItem(new CButton("select","Select"));
 			}
-			else
-			{
+			else{
 				$r_header = null;
 			}
 
-			if( ($l_header || $r_header) &&
-				!isset($_REQUEST['fullscreen'])
-				)
+			if(($l_header || $r_header) &&	($_REQUEST['fullscreen']==0))
 					show_table_header($l_header,$r_header);
 		}
-		else
-		{
-			echo $l_header."\n";
+		else{
+			$txt = new CTag('p','yes',$l_header);
+			$txt->Show();
+			echo "\n";
 		}
 
 		$cond_clock = "";
 		$limit = "NO";
 		if($_REQUEST["action"]=="showlatest"){
 			$limit = 500;
-		} elseif($_REQUEST["action"]=="showvalues"){
+		} 
+		else if($_REQUEST["action"]=="showvalues"){
 			$cond_clock = " and h.clock>$time and h.clock<$till";
 		}
 
-		if($item_type==ITEM_VALUE_TYPE_LOG)
-		{
-			$itemid_lst = "";
-			if(is_array($_REQUEST["itemid"]))
-			{
+		if($item_type==ITEM_VALUE_TYPE_LOG){
+			$itemid_lst = '';
+			
+			if(is_array($_REQUEST["itemid"])){
 				$itemid_lst = implode(',',$_REQUEST["itemid"]);
 				$item_cout = count($_REQUEST["itemid"]);
 			}
-			else
-			{
+			else{
 				$itemid_lst = $_REQUEST["itemid"];
 				$item_cout = 1;
 			}
 
-			$sql_filter = "";
-			if(isset($_REQUEST["filter"]) && $_REQUEST["filter"]!="")
-			{
+			$sql_filter = '';
+			if(isset($_REQUEST["filter"]) && $_REQUEST["filter"]!=""){
 				if($_REQUEST["filter_task"] == FILTER_TAST_SHOW)
-					$sql_filter = " and h.value like ".zbx_dbstr("%".$_REQUEST["filter"]."%")."";
-				elseif($_REQUEST["filter_task"] == FILTER_TAST_HIDE)
-					$sql_filter = " and h.value not like ".zbx_dbstr("%".$_REQUEST["filter"]."%")."";
+					$sql_filter = ' AND h.value LIKE '.zbx_dbstr("%".$_REQUEST["filter"]."%");
+				else if($_REQUEST["filter_task"] == FILTER_TAST_HIDE)
+					$sql_filter = ' AND h.value NOT LIKE '.zbx_dbstr("%".$_REQUEST["filter"]."%");
 			}
 
 
-			$sql = "select hst.host,i.itemid,i.key_,i.description,h.clock,h.value,i.valuemapid,h.timestamp,h.source,h.severity".
-				" from history_log h, items i, hosts hst".
-				" where hst.hostid=i.hostid and h.itemid=i.itemid".$sql_filter." and i.itemid in (".$itemid_lst.")".$cond_clock.
-				" order by h.clock desc, h.id desc";
+			$sql = 'SELECT hst.host,i.itemid,i.key_,i.description,h.clock,h.value,i.valuemapid,h.timestamp,h.source,h.severity'.
+					' FROM history_log h, items i, hosts hst'.
+					' WHERE hst.hostid=i.hostid '.
+						' AND h.itemid=i.itemid'.$sql_filter.
+						' AND i.itemid in ('.$itemid_lst.')'.$cond_clock.
+					' ORDER BY h.clock desc, h.id desc';
 
 			$result=DBselect($sql,$limit);
 
-			if(!isset($_REQUEST["plaintext"]))
-			{
+			if(!isset($_REQUEST['plaintext'])){
 				$table = new CTableInfo('...','log_history_table');
+				$table->AddOption('id','graph');
 				$table->SetHeader(array(S_TIMESTAMP,
 					$item_cout > 1 ? S_ITEM : null,
 					S_LOCAL_TIME,S_SOURCE,S_SEVERITY,S_VALUE),"header");
 
 				$table->ShowStart(); // to solve memory leak we call 'Show' method by steps
 			}
-			else
-			{
-				echo "<PRE>\n";
+			else{
+				echo "<pre>\n";
 			}
 
-			while($row=DBfetch($result))
-			{
+			while($row=DBfetch($result)){
 				$color_style = null;
 
-				if(isset($_REQUEST["filter"]) && $_REQUEST["filter"]!="")
-				{
-					$contain = stristr($row["value"],$_REQUEST["filter"]) ? TRUE : FALSE;
+				if(isset($_REQUEST["filter"]) && $_REQUEST["filter"]!=""){
+					$contain = zbx_stristr($row["value"],$_REQUEST["filter"]) ? TRUE : FALSE;
 
 					if(!isset($_REQUEST["mark_color"])) $_REQUEST["mark_color"] = MARK_COLOR_RED;
 
@@ -366,8 +389,7 @@ include_once "include/page_header.php";
 					if((!$contain) && ($_REQUEST["filter_task"] == FILTER_TAST_INVERT_MARK))
 						$color_style = $_REQUEST["mark_color"];
 
-					switch($color_style)
-					{
+					switch($color_style){
 						case MARK_COLOR_RED:	$color_style="mark_as_red"; break;
 						case MARK_COLOR_GREEN:	$color_style="mark_as_green"; break;
 						case MARK_COLOR_BLUE:	$color_style="mark_as_blue"; break;
@@ -377,23 +399,19 @@ include_once "include/page_header.php";
 				$new_row = array(nbsp(date("[Y.M.d H:i:s]",$row["clock"])));
 
 				if($item_cout > 1)
-					array_push($new_row,$row["host"].":".item_description($row["description"],$row["key_"]));
+					array_push($new_row,$row["host"].":".item_description($row));
 
-				if($row["timestamp"] == 0)
-				{
+				if($row["timestamp"] == 0){
 					array_push($new_row,new CCol("-","center"));
 				}
-				else
-				{
+				else{
 					array_push($new_row,date("Y.M.d H:i:s",$row["timestamp"]));
 				}
 				
-				if($row["source"] == "")
-				{
+				if($row["source"] == ""){
 					array_push($new_row,new CCol("-","center"));
 				}
-				else
-				{
+				else{
 					array_push($new_row,$row["source"]);
 				}
 
@@ -406,71 +424,66 @@ include_once "include/page_header.php";
 
 				$row["value"] = trim($row["value"],"\r\n");
 //				array_push($new_row,htmlspecialchars($row["value"]));
-				array_push($new_row,htmlspecialchars(encode_log($row["value"])));
+				array_push($new_row,encode_log($row["value"]));
 
-				if(!isset($_REQUEST["plaintext"]))
-				{
+				if(!isset($_REQUEST["plaintext"])){
 
 					$crow = new CRow($new_row); 
 
-					if(is_null($color_style) && is_array($_REQUEST["itemid"]))
-					{
+					if(is_null($color_style) && is_array($_REQUEST["itemid"])){
 						$min_color = 0x98;
 						$max_color = 0xF8;
 						$int_color = ($max_color - $min_color) / count($_REQUEST["itemid"]);
 						$int_color *= array_search($row["itemid"],$_REQUEST["itemid"]);
 						$int_color += $min_color;
 						$crow->AddOption("style","background-color: ".sprintf("#%X%X%X",$int_color,$int_color,$int_color));
-					} else {
+					} 
+					else {
 						$crow->SetClass($color_style);
 					}
 
 					$crow->Show();	// to solve memory leak we call 'Show' method for each element
 				}
-				else
-				{
+				else{
 					echo date("Y-m-d H:i:s",$row["clock"]);
-					echo "\t".$row["clock"]."\t".$row["value"]."\n";
+					echo "\t".$row["clock"]."\t".htmlspecialchars($row["value"])."\n";
 				}
 			}
 			if(!isset($_REQUEST["plaintext"]))
 				$table->ShowEnd();	// to solve memory leak we call 'Show' method by steps
 			else
-				echo "</PRE>";
+				echo "</pre>";
 		}
-		else
-		{
-			switch($item_type)
-			{
+		else{
+			switch($item_type){
 				case ITEM_VALUE_TYPE_FLOAT:	$h_table = "history";		break;
 				case ITEM_VALUE_TYPE_UINT64:	$h_table = "history_uint";	break;
 				case ITEM_VALUE_TYPE_TEXT:	$h_table = "history_text";	break;
 				default:			$h_table = "history_str";
 			}
 
-			$result = DBselect("select h.clock,h.value,i.valuemapid from $h_table h, items i".
-					" where h.itemid=i.itemid and i.itemid=".$_REQUEST["itemid"].
-					$cond_clock." order by clock desc",
+			$result = DBselect('SELECT h.clock,h.value,i.valuemapid '.
+							' FROM '.$h_table.' h, items i '.
+							' WHERE h.itemid=i.itemid '.
+								' AND i.itemid='.$_REQUEST['itemid'].
+								$cond_clock.
+							' ORDER BY clock desc',
 				$limit);
 
-			if(!isset($_REQUEST["plaintext"]))
-			{
+			if(!isset($_REQUEST["plaintext"])){
 				$table = new CTableInfo();
 				$table->SetHeader(array(S_TIMESTAMP, S_VALUE));
-
+				$table->AddOption('id','graph');
 				$table->ShowStart(); // to solve memory leak we call 'Show' method by steps
 			}
-			else
-			{
-				echo "<PRE>\n";
+			else{
+				echo "<pre>\n";
 			}
 
 COpt::profiling_start("history");
-			while($row=DBfetch($result))
-			{
+			while($row=DBfetch($result)){
 				
-				if($DB_TYPE == "ORACLE" && $item_type == ITEM_VALUE_TYPE_TEXT)
-				{
+				if($DB['TYPE'] == "ORACLE" && $item_type == ITEM_VALUE_TYPE_TEXT){
 					if(isset($row["value"]))
 						$row["value"] = $row["value"]->load();
 					else
@@ -483,35 +496,56 @@ COpt::profiling_start("history");
 					$value = $row["value"]; 
 
 				$new_row = array(date("Y.M.d H:i:s",$row["clock"]));
-				if(str_in_array($item_type,array(ITEM_VALUE_TYPE_FLOAT,ITEM_VALUE_TYPE_UINT64)))
-				{
+				if(str_in_array($item_type,array(ITEM_VALUE_TYPE_FLOAT,ITEM_VALUE_TYPE_UINT64))){
 					array_push($new_row,$value);
 				}
-				else
-				{
-					array_push($new_row,array("<pre>",htmlspecialchars($value),"</pre>"));
+				else{
+					$pre = new CTag('pre','yes');
+					$pre->AddItem($value);
+					
+					array_push($new_row,$pre);
 				}
-				if(!isset($_REQUEST["plaintext"]))
-				{
+				
+				if(!isset($_REQUEST["plaintext"])){
 					$table->ShowRow($new_row);
 				}
-				else
-				{
+				else{
 					echo date("Y-m-d H:i:s",$row["clock"]);
-					echo "\t".$row["clock"]."\t".$row["value"]."\n";
+					echo "\t".$row["clock"]."\t".htmlspecialchars($row["value"])."\n";
 				}
 			}
-			if(!isset($_REQUEST["plaintext"]))
+			if(!isset($_REQUEST["plaintext"])){
 				$table->ShowEnd();	// to solve memory leak we call 'Show' method by steps
-			else
-				echo "</PRE>";
+				echo SBR;
+			}
+			else{
+				echo "</pre>";
+			}
 COpt::profiling_stop("history");
 		}
 	}
 
 	if(!isset($_REQUEST["plaintext"])){
-		if(($_REQUEST["action"]=="showvalues") || ($_REQUEST['action'] == "showgraph")){
-			navigation_bar("history.php",$to_save_request);
+	
+		if(str_in_array($_REQUEST["action"],array("showvalues","showgraph"))){
+			
+			$stime = get_min_itemclock_by_itemid($_REQUEST["itemid"]);
+			$stime = (is_null($stime))?0:$stime;
+			$bstime = time()-$effectiveperiod;
+			
+			if(isset($_REQUEST['stime'])){
+				$bstime = $_REQUEST['stime'];
+				$bstime = mktime(substr($bstime,8,2),substr($bstime,10,2),0,substr($bstime,4,2),substr($bstime,6,2),substr($bstime,0,4));
+			}
+			
+ 			$script = 	'scrollinit(0,'.$effectiveperiod.','.$stime.',0,'.$bstime.');
+						showgraphmenu("graph");';
+			if(isset($dom_graph_id))
+						$script.='graph_zoom_init("'.$dom_graph_id.'",'.$bstime.','.$effectiveperiod.',ZBX_G_WIDTH, 200, true);';
+							
+			zbx_add_post_js($script); 
+
+//		navigation_bar("history.php",$to_save_request);
 		}
 	}
 ?>
