@@ -42,6 +42,7 @@
 		$str_resource[AUDIT_RESOURCE_SCENARIO]		= S_SCENARIO;
 		$str_resource[AUDIT_RESOURCE_DISCOVERY_RULE]	= S_DISCOVERY_RULE;
 		$str_resource[AUDIT_RESOURCE_SLIDESHOW]		= S_SLIDESHOW;
+		$str_resource[AUDIT_RESOURCE_PROXY]		= S_PROXY;
 
 		if(isset($str_resource[$resource_type]))
 			return $str_resource[$resource_type];
@@ -49,16 +50,14 @@
 		return S_UNKNOWN_RESOURCE;
 	}
 
-	function add_audit_if($condition,$action,$resourcetype,$details)
-	{
+	function add_audit_if($condition,$action,$resourcetype,$details){
 		if($condition) 
 			return add_audit($action,$resourcetype,$details);
 
 		return false;
 	}
 	
-	function add_audit($action,$resourcetype,$details)
-	{
+	function add_audit($action,$resourcetype,$details){
 		global $USER_DETAILS;
 
 		if(!isset($USER_DETAILS["userid"]))	check_authorisation();
@@ -68,7 +67,7 @@
 		if(strlen($details) > 128)
 			$details = substr($details, 0, 125).'...';
 
-		if(($result = DBexecute("insert into auditlog (auditid,userid,clock,action,resourcetype,details) ".
+		if(($result = DBexecute('INSERT INTO auditlog (auditid,userid,clock,action,resourcetype,details) '.
 			" values ($auditid,".$USER_DETAILS["userid"].",".time().",$action,$resourcetype,".zbx_dbstr($details).")")))
 		{
 			$result = $auditid;
