@@ -23,6 +23,7 @@
 /* public */
 		function CCol($item=NULL,$class=NULL){
 			parent::CTag("td","yes");
+			
 			$this->AddItem($item);
 			$this->SetClass($class);
 		}
@@ -48,6 +49,7 @@
 /* public */
 		function CRow($item=NULL,$class=NULL){
 			parent::CTag("tr","yes");
+
 			$this->AddItem($item);
 			$this->SetClass($class);
 		}
@@ -62,15 +64,16 @@
 			}
 			elseif(is_array($item)){
 				foreach($item as $el){
-                        		if(strtolower(get_class($el))=='ccol') {
-                		        	parent::AddItem($el);
-					} elseif(!is_null($el)) {
-						parent::AddItem('<td>'.unpack_object($el).'</td>');
+					if(strtolower(get_class($el))=='ccol') {
+						parent::AddItem($el);
+					} 
+					else if(!is_null($el)){
+						parent::AddItem(new CCol($el));
 					}
 				}
 			}
 			elseif(!is_null($item)){
-				parent::AddItem('<td>'.unpack_object($item).'</td>');
+				parent::AddItem(new CCol($item));
 			}
 		}
 		
@@ -104,7 +107,7 @@
 			$this->headerClass = NULL;
 			$this->footer = '';
 			$this->footerClass = NULL;
-			$this->colnum = 0;
+			$this->colnum = 1;
 
 			$this->message = $message;
 		}
@@ -150,10 +153,11 @@
                                                 $this->oddRowClass:
                                                 $this->evenRowClass);
 			}/**/
-			return $item->ToString();
+			return $item;
 		}
 
 		function SetHeader($value=NULL,$class=NULL){
+			if(isset($_REQUEST['print'])) hide_form_items($value);
 			if(is_null($class)) $class = $this->headerClass;
 
 			if(strtolower(get_class($value))=='crow') {
@@ -166,9 +170,11 @@
 		}
 
 		function SetFooter($value=NULL,$class=NULL){
+			if(isset($_REQUEST['print'])) hide_form_items($value);
 			if(is_null($class)) $class = $this->footerClass;
 
-			$this->footer = $this->PrepareRow($value,$class);;
+			$this->footer = $this->PrepareRow($value,$class);
+			$this->footer = $this->footer->ToString();
 		}
 
 		function AddRow($item,$rowClass=NULL){
@@ -178,7 +184,11 @@
 		}
 
 		function ShowRow($item,$rowClass=NULL){
-			echo $this->PrepareRow($item,$rowClass);
+			// needed for PHP4
+			$tempobj = $this->PrepareRow($item,$rowClass);
+			echo $tempobj->ToString();
+			unset($tempobj);
+			//---------------
 			++$this->rownum;
 		}
 /* protected */
@@ -196,6 +206,7 @@
 			$ret = "";
 			if($this->rownum == 0 && isset($this->message)) {
 				$ret = $this->PrepareRow(new CCol($this->message,'message'));
+				$ret = $ret->ToString();
 			}
 			$ret .= $this->footer;
 			$ret .= parent::EndToString();
