@@ -21,7 +21,7 @@
 <?php
 	require_once "include/config.inc.php";
 	require_once "include/maps.inc.php";
-
+		
 	$page["title"] = "S_MAP";
 	$page["file"] = "map.php";
 	$page["type"] = PAGE_TYPE_IMAGE;
@@ -40,7 +40,7 @@ include_once "include/page_header.php";
 	check_fields($fields);
 ?>
 <?php
-	if(!sysmap_accessiable($_REQUEST["sysmapid"],PERM_READ_ONLY))
+	if(!sysmap_accessible($_REQUEST["sysmapid"],PERM_READ_ONLY))
 	{
 		access_deny();
 	}
@@ -110,17 +110,14 @@ include_once "include/page_header.php";
 	$str=date("m.d.Y H:i:s",time(NULL));
 	ImageString($im, 0,imagesx($im)-120,imagesy($im)-12,"$str", $gray);
 
-	if(!isset($_REQUEST["noedit"]))
-	{
+	if(!isset($_REQUEST["noedit"])){
 		$grid = 50;
 
-		for($x=$grid;$x<$width;$x+=$grid)
-		{
+		for($x=$grid;$x<$width;$x+=$grid){
 			MyDrawLine($im,$x,0,$x,$height,$black,GRAPH_DRAW_TYPE_DASHEDLINE);
 			ImageString($im, 2, $x+2,2, $x , $black);
 		}
-		for($y=$grid;$y<$height;$y+=$grid)
-		{
+		for($y=$grid;$y<$height;$y+=$grid){
 			MyDrawLine($im,0,$y,$width,$y,$black,GRAPH_DRAW_TYPE_DASHEDLINE);
 			ImageString($im, 2, 2,$y+2, $y , $black);
 		}
@@ -136,17 +133,23 @@ include_once "include/page_header.php";
 		list($x1, $y1) = get_icon_center_by_selementid($link["selementid1"]);
 		list($x2, $y2) = get_icon_center_by_selementid($link["selementid2"]);
 
-		$drawtype = $link["drawtype_off"];
-		$color = $colors[$link["color_off"]];
+		$drawtype = $link["drawtype"];
+		$color = convertColor($im,$link["color"]);
 
-		if(!is_null($link["triggerid"]))
-		{
-			$trigger=get_trigger_by_triggerid($link["triggerid"]);
-//			if($trigger["value"] == TRIGGER_VALUE_TRUE)
-			if($trigger["status"] == TRIGGER_STATUS_ENABLED && $trigger["value"] == TRIGGER_VALUE_TRUE)
-			{
-				$drawtype = $link["drawtype_on"];
-				$color = $colors[$link["color_on"]];
+		$triggers = get_link_triggers($link['linkid']);
+		
+		
+		if(!empty($triggers)){
+			$max_severity=0;
+			foreach($triggers as $id => $link_trigger){
+				$triggers[$id]=array_merge($link_trigger,get_trigger_by_triggerid($link_trigger["triggerid"]));
+				if($triggers[$id]["status"] == TRIGGER_STATUS_ENABLED && $triggers[$id]["value"] == TRIGGER_VALUE_TRUE){
+					if($triggers[$id]['severity'] >= $max_severity){
+						$drawtype = $triggers[$id]['drawtype'];
+						$color = convertColor($im,$triggers[$id]['color']);
+						$max_severity=$triggers[$id]['severity'];
+					}
+				}
 			}
 		}
 		MyDrawLine($im,$x1,$y1,$x2,$y2,$color,$drawtype);
@@ -187,6 +190,12 @@ include_once "include/page_header.php";
 			$label_line = $el_info['name'];
 		}
 
+		if (isset($el_info['disabled']) && $el_info['disabled'] == 1)
+		{
+			$info_line = 'DISABLED';
+			$label_color = $gray;
+		}
+
 		unset($el_info);
 
 		if($db_element["elementtype"] == SYSMAP_ELEMENT_TYPE_HOST)
@@ -195,9 +204,6 @@ include_once "include/page_header.php";
 			
 			if( $label_type==MAP_LABEL_TYPE_IP )
 				$label_line=$host["ip"];
-
-			if( $host["status"] == HOST_STATUS_NOT_MONITORED )
-				$label_color=$darkred;
 		}
 
 		if($label_line=="" && $info_line=="")	continue;
