@@ -24,6 +24,7 @@
 
 	$page["title"] = "S_IT_SERVICES_AVAILABILITY_REPORT";
 	$page["file"] = "report3.php";
+	$page['hist_arg'] = array();
 	
 include_once "include/page_header.php";
 
@@ -44,24 +45,23 @@ include_once "include/page_header.php";
 	define("YEAR_LEFT_SHIFT", 5);
 ?>
 <?php
-	if(! (DBfetch(DBselect('select serviceid from services where serviceid='.$_REQUEST["serviceid"]))) )
-	{
+	if(!DBfetch(DBselect('select serviceid from services where serviceid='.$_REQUEST["serviceid"]))){
 		fatal_error(S_NO_IT_SERVICE_DEFINED);
 	}
-
-	$denyed_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_MODE_LT);
 	
-	if( !($service = DBfetch(DBselect("select s.* from services s left join triggers t on s.triggerid=t.triggerid ".
-		" left join functions f on t.triggerid=f.triggerid left join items i on f.itemid=i.itemid ".
-		" where (i.hostid is NULL or i.hostid not in (".$denyed_hosts.")) ".
-		' and '.DBin_node('s.serviceid').
-		" and s.serviceid=".$_REQUEST["serviceid"]
-		))))
-	{
+	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, PERM_RES_IDS_ARRAY);
+	
+	$sql = 'SELECT s.* '.
+			' FROM services s '.
+			' WHERE s.serviceid='.$_REQUEST['serviceid'].
+				' AND (s.triggerid IS NULL OR '.DBcondition('s.triggerid',$available_triggers).') '.
+				' AND '.DBin_node('s.serviceid');
+				
+	if(!$service = DBfetch(DBselect($sql))){
 		access_deny();
 	}
 ?>
-<?php
+<?php	
 	$form = new CForm();
 	$form->SetMethod('get');
 	$form->AddVar("serviceid", $_REQUEST["serviceid"]);
@@ -74,10 +74,11 @@ include_once "include/page_header.php";
 	$form->AddItem(array(SPACE.S_PERIOD.SPACE, $cmbPeriod));
 
 	$cmbYear = new CComboBox("year", $year, "submit();");
-	for($y = (date("Y") - YEAR_LEFT_SHIFT); $y <= date("Y"); $y++)
-	{
+	
+	for($y = (date("Y") - YEAR_LEFT_SHIFT); $y <= date("Y"); $y++){
 		$cmbYear->AddItem($y, $y);
 	}
+	
 	$form->AddItem(array(SPACE.S_YEAR.SPACE, $cmbYear));
 
 	show_table_header(array(
@@ -93,50 +94,48 @@ include_once "include/page_header.php";
 	
 	$header = array(S_OK,S_PROBLEMS,S_DOWNTIME,S_PERCENTAGE,S_SLA);
 
-        switch($period)
-	{
-		case "yearly":
-			$from	= (date("Y") - YEAR_LEFT_SHIFT);
-			$to	= date("Y");
-			array_unshift($header, new CCol(S_YEAR,"center"));
-			function get_time($y)	{	return mktime(0,0,0,1,1,$y);		}
-			function format_time($t){	return date("Y", $t);			}
-			function format_time2($t){	return null; };
-			break;
-		case "monthly":
-			$from	= 1;
-			$to	= 12;
-			array_unshift($header, new CCol(S_MONTH,"center"));
-			function get_time($m)	{	global $year;	return mktime(0,0,0,$m,1,$year);	}
-			function format_time($t){	return date("M Y",$t);			}
-			function format_time2($t){	return null; };
-			break;
-		case "dayly":
-			$from	= 1;
-			$to	= 365;
-			array_unshift($header, new CCol(S_DAY,"center"));
-			function get_time($d)	{	global $year;	return mktime(0,0,0,1,$d,$year);	}
-			function format_time($t){	return date("d M Y",$t);		}
-			function format_time2($t){	return null; };
-			break;
-		case "weekly":
-		default:
-			$from	= 0;
-			$to	= 52;
-			array_unshift($header,new CCol(S_FROM,"center"),new CCol(S_TILL,"center"));
-			function get_time($w)	{
-				global $year;	
-
-				$time	= mktime(0,0,0,1, 1, $year);
-				$wd	= date("w", $time);
-				$wd	= $wd == 0 ? 6 : $wd - 1;
-
-				return ($time + ($w*7 - $wd)*24*3600);
-			}
-			function format_time($t){	return date("d M Y H:i",$t);	}
-			function format_time2($t){	return format_time($t); };
-			break;
-
+        switch($period){
+			case "yearly":
+				$from	= (date("Y") - YEAR_LEFT_SHIFT);
+				$to	= date("Y");
+				array_unshift($header, new CCol(S_YEAR,"center"));
+				function get_time($y)	{	return mktime(0,0,0,1,1,$y);		}
+				function format_time($t){	return date("Y", $t);			}
+				function format_time2($t){	return null; };
+				break;
+			case "monthly":
+				$from	= 1;
+				$to	= 12;
+				array_unshift($header, new CCol(S_MONTH,"center"));
+				function get_time($m)	{	global $year;	return mktime(0,0,0,$m,1,$year);	}
+				function format_time($t){	return date("M Y",$t);			}
+				function format_time2($t){	return null; };
+				break;
+			case "dayly":
+				$from	= 1;
+				$to	= 365;
+				array_unshift($header, new CCol(S_DAY,"center"));
+				function get_time($d)	{	global $year;	return mktime(0,0,0,1,$d,$year);	}
+				function format_time($t){	return date("d M Y",$t);		}
+				function format_time2($t){	return null; };
+				break;
+			case "weekly":
+			default:
+				$from	= 0;
+				$to	= 52;
+				array_unshift($header,new CCol(S_FROM,"center"),new CCol(S_TILL,"center"));
+				function get_time($w)	{
+					global $year;	
+	
+					$time	= mktime(0,0,0,1, 1, $year);
+					$wd	= date("w", $time);
+					$wd	= $wd == 0 ? 6 : $wd - 1;
+	
+					return ($time + ($w*7 - $wd)*24*3600);
+				}
+				function format_time($t){	return date("d M Y H:i",$t);	}
+				function format_time2($t){	return format_time($t); };
+				break;
 	}
 
 	$table->SetHeader($header);
