@@ -121,8 +121,8 @@
 #define OFF	0
 
 #define	APPLICATION_NAME	"ZABBIX Agent"
-#define	ZABBIX_REVDATE		"23 July 2008"
-#define	ZABBIX_VERSION		"1.4.6"
+#define	ZABBIX_REVDATE		"04 November 2008"
+#define	ZABBIX_VERSION		"1.6.1"
 
 #if defined(_WINDOWS)
 extern char ZABBIX_SERVICE_NAME[64];
@@ -179,7 +179,9 @@ typedef enum
 	ITEM_TYPE_ZABBIX_ACTIVE,
 	ITEM_TYPE_AGGREGATE,
 	ITEM_TYPE_HTTPTEST,
-	ITEM_TYPE_EXTERNAL
+	ITEM_TYPE_EXTERNAL,
+	ITEM_TYPE_DB_MONITOR,
+	ITEM_TYPE_IPMI
 } zbx_item_type_t;
 
 /* Event sources */
@@ -200,7 +202,9 @@ typedef enum
 typedef enum
 {
 	DOBJECT_STATUS_UP	= 0,
-	DOBJECT_STATUS_DOWN
+	DOBJECT_STATUS_DOWN,
+	DOBJECT_STATUS_DISCOVER,
+	DOBJECT_STATUS_LOST
 } zbx_dstatus_t;
 
 /* Item value types */
@@ -234,7 +238,8 @@ typedef enum
 	SVC_TCP,
 	SVC_AGENT,
 	SVC_SNMPv1,
-	SVC_SNMPv2c
+	SVC_SNMPv2c,
+	SVC_ICMPPING
 } zbx_dservice_type_t;
 
 
@@ -248,9 +253,12 @@ typedef enum
 #define ITEM_MULTIPLIER_USE			1
 
 /* Item delta types */
-#define ITEM_STORE_AS_IS		0
-#define ITEM_STORE_SPEED_PER_SECOND	1
-#define ITEM_STORE_SIMPLE_CHANGE	2
+typedef enum
+{
+	ITEM_STORE_AS_IS = 0,
+	ITEM_STORE_SPEED_PER_SECOND,
+	ITEM_STORE_SIMPLE_CHANGE
+} zbx_item_store_type_t;
 
 /* Object types for operations */
 #define OPERATION_OBJECT_USER	0
@@ -279,7 +287,10 @@ typedef enum
 	CONDITION_TYPE_DSERVICE_PORT,
 	CONDITION_TYPE_DSTATUS,
 	CONDITION_TYPE_DUPTIME,
-	CONDITION_TYPE_DVALUE
+	CONDITION_TYPE_DVALUE,
+	CONDITION_TYPE_HOST_TEMPLATE,
+	CONDITION_TYPE_EVENT_ACKNOWLEDGED,
+	CONDITION_TYPE_APPLICATION
 } zbx_condition_type_t;
 
 /* Condition operators */
@@ -312,33 +323,71 @@ typedef enum
 /* Special item key used for internal ZABBIX log */
 #define SERVER_ZABBIXLOG_KEY	"zabbix[log]"
 
-/* Alert types */
+/* Media types */
 typedef enum
 {
-	ALERT_TYPE_EMAIL = 0,
-	ALERT_TYPE_EXEC,
-	ALERT_TYPE_SMS,
-	ALERT_TYPE_JABBER
-} zbx_alert_type_t;
+	MEDIA_TYPE_EMAIL = 0,
+	MEDIA_TYPE_EXEC,
+	MEDIA_TYPE_SMS,
+	MEDIA_TYPE_JABBER
+} zbx_media_type_t;
 
 /* Alert statuses */
 typedef enum
 {
 	ALERT_STATUS_NOT_SENT = 0,
-	ALERT_STATUS_SENT
+	ALERT_STATUS_SENT,
+	ALERT_STATUS_FAILED
 } zbx_alert_status_t;
 
+/* Escalation stauses */
+typedef enum
+{
+	ESCALATION_STATUS_ACTIVE = 0,
+	ESCALATION_STATUS_RECOVERY,
+	ESCALATION_STATUS_SLEEP,
+	ESCALATION_STATUS_COMPLETED /* only in server code */
+} zbx_escalation_status_t;
+
+/* Alert types */
+typedef enum
+{
+	ALERT_TYPE_MESSAGE = 0,
+	ALERT_TYPE_COMMAND
+} zbx_alert_type_t;
+
 /* Item statuses */
 typedef enum
 {
 	ITEM_STATUS_ACTIVE = 0,
 	ITEM_STATUS_DISABLED,
-/*ITEM_STATUS_TRAPPED	2*/
+/*ITEM_STATUS_TRAPPED		2*/
 	ITEM_STATUS_NOTSUPPORTED = 3,
-	ITEM_STATUS_DELETED,
-	ITEM_STATUS_NOTAVAILABLE
+/*ITEM_STATUS_DELETED		4*/
+/*ITEM_STATUS_NOTAVAILABLE	5*/
 } zbx_item_status_t;
 
+/* Trigger types */
+typedef enum
+{
+	TRIGGER_TYPE_NORMAL = 0,
+	TRIGGER_TYPE_MULTIPLE_TRUE
+} zbx_trigger_type_t;
+
+/* GROUP statuses */
+typedef enum
+{
+       GROUP_STATUS_ACTIVE = 0,
+       GROUP_STATUS_DISABLED
+} zbx_group_status_type_t;
+
+/* process type */
+typedef enum
+{
+	ZBX_PROCESS_SERVER = 0,
+	ZBX_PROCESS_PROXY
+} zbx_process_t;
+
 /* HTTP Tests statuses */
 #define HTTPTEST_STATUS_MONITORED	0
 #define HTTPTEST_STATUS_NOT_MONITORED	1
@@ -353,6 +402,7 @@ typedef enum
 /*#define HOST_STATUS_UNREACHABLE	2*/
 #define HOST_STATUS_TEMPLATE	3
 #define HOST_STATUS_DELETED	4
+#define HOST_STATUS_PROXY	5
 
 /* Host availability */
 #define HOST_AVAILABLE_UNKNOWN	0
@@ -395,6 +445,9 @@ typedef enum
 #define ACTION_STATUS_ACTIVE	0
 #define ACTION_STATUS_DISABLED	1
 
+/* Max number of retries for alerts */
+#define ALERT_MAX_RETRIES	3
+
 /* Operation types */
 #define OPERATION_TYPE_MESSAGE		0
 #define OPERATION_TYPE_COMMAND		1
@@ -427,13 +480,6 @@ typedef enum
 #define	ZBX_TYPE_UINT	5
 #define	ZBX_TYPE_ID	6
 
-/* Flags for node history exchange */
-#define	ZBX_TABLE_HISTORY	0
-#define	ZBX_TABLE_HISTORY_UINT	1
-#define	ZBX_TABLE_HISTORY_STR	2
-#define	ZBX_TABLE_HISTORY_LOG	3
-#define	ZBX_TABLE_HISTORY_TEXT	4
-
 /* HTTP item types */
 typedef enum
 {
@@ -444,7 +490,12 @@ typedef enum
 } zbx_httpitem_type_t;
 
 /* Flags */
-#define	ZBX_SYNC	1
+#define	ZBX_SYNC		0x01
+#define ZBX_NOTNULL		0x02
+#define ZBX_HISTORY		0x04
+#define ZBX_HISTORY_SYNC	0x08
+#define ZBX_HISTORY_TRENDS	0x10
+#define ZBX_PROXY		0x20
 
 /* Types of nodes */
 #define	ZBX_NODE_TYPE_REMOTE	0
@@ -454,6 +505,7 @@ typedef enum
 
 #define	ZBX_POLLER_TYPE_NORMAL		0
 #define	ZBX_POLLER_TYPE_UNREACHABLE	1
+#define	ZBX_POLLER_TYPE_IPMI		2
 
 #define	POLLER_TIMEOUT	5
 /* Do not perform more than this number of checks during unavailability period */
@@ -462,7 +514,7 @@ typedef enum
 
 #define	AGENT_TIMEOUT	3
 
-#define	SENDER_TIMEOUT		5
+#define	SENDER_TIMEOUT		60
 #define	ZABBIX_TRAPPER_TIMEOUT	300
 #define	SNMPTRAPPER_TIMEOUT	5
 
@@ -487,9 +539,10 @@ void    *zbx_realloc(void *src, size_t size);
 	
 #define zbx_fclose(f) { if(f){ fclose(f); f = NULL; } }
 
-#define ZBX_COND_NODEID " %s>=100000000000000*%d and %s<=(100000000000000*%d+99999999999999) "
+/*#define ZBX_COND_NODEID " %s>=100000000000000*%d and %s<=(100000000000000*%d+99999999999999) "*/
+/*#define ZBX_COND_NODEID " %s>=%d00000000000000 and %s<=%d99999999999999 "
 #define LOCAL_NODE(fieldid) fieldid, CONFIG_NODEID, fieldid, CONFIG_NODEID
-#define ZBX_NODE(fieldid,nodeid) fieldid, nodeid, fieldid, nodeid
+#define ZBX_NODE(fieldid,nodeid) fieldid, nodeid, fieldid, nodeid*/
 
 #define MIN_ZABBIX_PORT 1024u
 #define MAX_ZABBIX_PORT 65535u
@@ -549,16 +602,21 @@ void	rtrim_spaces(char *c);
 void	delete_reol(char *c);
 int	get_param(const char *param, int num, char *buf, int maxlen);
 int	num_param(const char *param);
+int	get_key_param(char *param, int num, char *buf, int maxlen);
+int	num_key_param(char *param);
 int	calculate_item_nextcheck(zbx_uint64_t itemid, int item_type, int delay, char *delay_flex, time_t now);
-int	check_time_period(const char *period, time_t now);
-void	zbx_binary2hex(const u_char *input, int ilen, char **output, int *olen);
+int	check_time_period(char *period, time_t now);
+char	zbx_num2hex(u_char c);
+u_char	zbx_hex2num(char c);
+int	zbx_binary2hex(const u_char *input, int ilen, char **output, int *olen);
 int     zbx_hex2binary(char *io);
 void	zbx_hex2octal(const char *input, char **output, int *olen);
 #ifdef HAVE_POSTGRESQL
 void	zbx_pg_escape_bytea(const u_char *input, int ilen, char **output, int *olen);
 int	zbx_pg_unescape_bytea(u_char *io);
 #endif
-char    *zbx_get_next_field(const char *line, char **output, int *olen, char separator);
+int	zbx_get_next_field(const char **line, char **output, int *olen, char separator);
+int	str_in_list(char *list, const char *value, const char delimiter);
 
 #ifdef HAVE___VA_ARGS__
 #	define zbx_setproctitle(fmt, ...) __zbx_zbx_setproctitle(ZBX_CONST_STRING(fmt), ##__VA_ARGS__)
@@ -594,6 +652,8 @@ int	zbx_vsnprintf(char* str, size_t count, const char *fmt, va_list args);
 #	define zbx_snprintf_alloc __zbx_zbx_snprintf_alloc
 #endif /* HAVE___VA_ARGS__ */
 void	__zbx_zbx_snprintf_alloc(char **str, int *alloc_len, int *offset, int max_len, const char *fmt, ...);
+void	zbx_strcpy_alloc(char **str, int *alloc_len, int *offset, const char *src);
+void	zbx_chrcpy_alloc(char **str, int *alloc_len, int *offset, const char src);
 
 size_t	zbx_strlcpy(char *dst, const char *src, size_t siz);
 size_t	zbx_strlcat(char *dst, const char *src, size_t siz);
@@ -654,6 +714,14 @@ int	ip_in_list(char *list, char *ip);
 #ifdef HAVE_IPV6
 int	expand_ipv6(const char *ip, char *str, size_t str_len );
 #endif /* HAVE_IPV6 */
+/* Time related functions */
+double	time_diff(struct timeval *from, struct timeval *to);
+char	*zbx_age2str(int age);
+
+int	uint64_array_add(zbx_uint64_t **values, int *alloc, int *num, zbx_uint64_t value);
+int	uint64_array_exists(zbx_uint64_t *values, int num, zbx_uint64_t value);
+void	uint64_array_rm(zbx_uint64_t *values, int *num, zbx_uint64_t *rm_values, int rm_num);
+
 int MAIN_ZABBIX_ENTRY(void);
 
 zbx_uint64_t	zbx_letoh_uint64(
@@ -663,5 +731,4 @@ zbx_uint64_t	zbx_letoh_uint64(
 zbx_uint64_t	zbx_htole_uint64(
 		zbx_uint64_t	data
 	);
-
 #endif
