@@ -26,6 +26,7 @@
 
 #include "common.h"
 #include "zbxdb.h"
+#include "dbschema.h"
 
 extern	char	*CONFIG_DBHOST;
 extern	char	*CONFIG_DBNAME;
@@ -35,8 +36,10 @@ extern	char	*CONFIG_DBSOCKET;
 extern	int	CONFIG_DBPORT;
 extern	int	CONFIG_NODEID;
 extern	int	CONFIG_MASTER_NODEID;
+extern	int	CONFIG_DBSYNCER_FORKS;
 extern	int	CONFIG_NODE_NOHISTORY;
 extern  int     CONFIG_REFRESH_UNSUPPORTED;
+extern	int	CONFIG_UNAVAILABLE_DELAY;
 
 typedef enum {
 	GRAPH_TYPE_NORMAL = 0,
@@ -100,13 +103,10 @@ typedef enum {
 #define DB_HTTPSTEP	struct zbx_httpstep_type
 #define DB_HTTPSTEPITEM	struct zbx_httpstepitem_type
 #define DB_HTTPTESTITEM	struct zbx_httptestitem_type
+#define DB_ESCALATION	struct zbx_escalation_type
 
-#define	MAX_HOST_HOST_LEN	64
-
-#define	MAX_ITEM_KEY_LEN	255
-#define	MAX_ITEM_IP_LEN		39
-#define	MAX_ITEM_SNMP_COMMUNITY_LEN	64
-#define	MAX_ITEM_SNMP_OID_LEN	255
+#define	HISTORY_STR_VALUE_LEN		255
+#define	HISTORY_STR_VALUE_LEN_MAX	HISTORY_STR_VALUE_LEN+1
 
 /* Trigger related defines */
 #define TRIGGER_DESCRIPTION_LEN		255
@@ -115,8 +115,6 @@ typedef enum {
 #define TRIGGER_EXPRESSION_LEN_MAX	TRIGGER_EXPRESSION_LEN+1
 #define TRIGGER_URL_LEN			255
 #define TRIGGER_URL_LEN_MAX		TRIGGER_URL_LEN+1
-#define TRIGGER_COMMENTS_LEN		4096
-#define TRIGGER_COMMENTS_LEN_MAX	TRIGGER_URL_LEN+1
 
 #define CONDITION_VALUE_LEN		255
 #define CONDITION_VALUE_LEN_MAX		CONDITION_VALUE_LEN+1
@@ -127,13 +125,21 @@ typedef enum {
 #define HOST_DNS_LEN_MAX		HOST_DNS_LEN+1
 #define HOST_IP_LEN			39
 #define HOST_IP_LEN_MAX			HOST_IP_LEN+1
+#define HOST_ADDR_LEN			64 /* MAX(HOST_DNS_LEN,HOST_IP_LEN) */
+#define HOST_ADDR_LEN_MAX		HOST_ADDR_LEN+1
 #define HOST_ERROR_LEN			128
 #define HOST_ERROR_LEN_MAX		HOST_ERROR_LEN+1
-#define HOST_ERROR_LEN			128
-#define HOST_ERROR_LEN_MAX		HOST_ERROR_LEN+1
+#define HOST_IPMI_USERNAME_LEN		128
+#define HOST_IPMI_USERNAME_LEN_MAX	HOST_IPMI_USERNAME_LEN+1
+#define HOST_IPMI_PASSWORD_LEN		128
+#define HOST_IPMI_PASSWORD_LEN_MAX	HOST_IPMI_PASSWORD_LEN+1
 
-#define ITEM_KEY_LEN			256
+#define ITEM_KEY_LEN			255
 #define ITEM_KEY_LEN_MAX		ITEM_KEY_LEN+1
+#define ITEM_LASTVALUE_LEN		255
+#define ITEM_LASTVALUE_LEN_MAX		ITEM_LASTVALUE_LEN+1
+#define ITEM_ERROR_LEN			128
+#define ITEM_ERROR_LEN_MAX		ITEM_ERROR_LEN+1
 
 #define GRAPH_NAME_LEN			128
 #define GRAPH_NAME_LEN_MAX		GRAPH_NAME_LEN+1
@@ -153,7 +159,10 @@ typedef enum {
 #define HTTPSTEP_REQUIRED_LEN		255
 #define HTTPSTEP_REQUIRED_LEN_MAX	HTTPSTEP_REQUIRED_LEN+1
 
-#define ZBX_SQL_ITEM_SELECT	"i.itemid,i.key_,h.host,h.port,i.delay,i.description,i.nextcheck,i.type,i.snmp_community,i.snmp_oid,h.useip,h.ip,i.history,i.lastvalue,i.prevvalue,i.hostid,h.status,i.value_type,h.errors_from,i.snmp_port,i.delta,i.prevorgvalue,i.lastclock,i.units,i.multiplier,i.snmpv3_securityname,i.snmpv3_securitylevel,i.snmpv3_authpassphrase,i.snmpv3_privpassphrase,i.formula,h.available,i.status,i.trapper_hosts,i.logtimefmt,i.valuemapid,i.delay_flex,h.dns from hosts h, items i"
+#define ZBX_SQL_ITEM_FIELDS	"i.itemid,i.key_,h.host,h.port,i.delay,i.description,i.nextcheck,i.type,i.snmp_community,i.snmp_oid,h.useip,h.ip,i.history,i.lastvalue,i.prevvalue,i.hostid,h.status,i.value_type,h.errors_from,i.snmp_port,i.delta,i.prevorgvalue,i.lastclock,i.units,i.multiplier,i.snmpv3_securityname,i.snmpv3_securitylevel,i.snmpv3_authpassphrase,i.snmpv3_privpassphrase,i.formula,h.available,i.status,i.trapper_hosts,i.logtimefmt,i.valuemapid,i.delay_flex,h.dns,i.params,i.trends,h.useipmi,h.ipmi_port,h.ipmi_authtype,h.ipmi_privilege,h.ipmi_username,h.ipmi_password,i.ipmi_sensor"
+#define ZBX_SQL_ITEM_TABLES	"hosts h, items i"
+#define ZBX_SQL_ITEM_FIELDS_NUM	46
+#define ZBX_SQL_ITEM_SELECT	ZBX_SQL_ITEM_FIELDS " from " ZBX_SQL_ITEM_TABLES
 
 #define ZBX_MAX_SQL_LEN			65535
 
@@ -199,7 +208,7 @@ DB_DSERVICE
 	int		lastup;
 	int		lastdown;
 	char		value[DSERVICE_VALUE_LEN_MAX];
-	char		key_[MAX_ITEM_KEY_LEN];
+	char		key_[ITEM_KEY_LEN_MAX];
 };
 
 DB_EVENT
@@ -216,6 +225,7 @@ DB_EVENT
 	int		trigger_priority;
 	char		*trigger_url;
 	char		*trigger_comments;
+	int		trigger_type;
 };
 
 DB_HOST
@@ -261,7 +271,8 @@ DB_ITEM
 	zbx_item_type_t	type;
 	zbx_item_status_t	status;
 	char	*description;
-	char	key[ITEM_KEY_LEN_MAX];
+	char	*key;
+	char	*key_orig;
 	char	*host_name;
 	char	*host_ip;
 	char	*host_dns;
@@ -311,6 +322,16 @@ DB_ITEM
 	char	*logtimefmt;
 	zbx_uint64_t	valuemapid;
 	char	*delay_flex;
+	char	*params;
+
+	int	useipmi;
+	char	*ipmi_ip;
+	int	ipmi_port;
+	int	ipmi_authtype;
+	int	ipmi_privilege;
+	char	*ipmi_username;
+	char	*ipmi_password;
+	char	*ipmi_sensor;
 };
  
 DB_FUNCTION
@@ -339,7 +360,7 @@ DB_MEDIA
 DB_MEDIATYPE
 {
 	zbx_uint64_t		mediatypeid;
-	zbx_alert_type_t	type;
+	zbx_media_type_t	type;
 	char	*description;
 	char	*smtp_server;
 	char	*smtp_helo;
@@ -361,6 +382,7 @@ DB_TRIGGER
 	int	value;
 /*	int	prevvalue; */
 	int	priority;
+	int	type;
 };
 
 DB_ACTION
@@ -370,6 +392,10 @@ DB_ACTION
 	int		evaltype;
 	int		status;
 	int		eventsource;
+	int		esc_period;
+	char		*shortdata;
+	char		*longdata;
+	int		recovery_msg;
 };
 
 DB_OPERATION
@@ -381,6 +407,9 @@ DB_OPERATION
 	zbx_uint64_t	objectid;
 	char		*shortdata;
 	char		*longdata;
+	int		esc_period;
+	int		default_msg;
+	int		evaltype;
 };
 
 DB_CONDITION
@@ -403,8 +432,8 @@ DB_ALERT
 	char	*subject;
 	char	*message;
 	zbx_alert_status_t	status;
-/*	int	retries;
-	int	delay;*/
+	int	retries;
+/*	int	delay;*/
 };
 
 DB_HOUSEKEEPER
@@ -435,7 +464,7 @@ DB_HTTPSTEP
 	zbx_uint64_t	httptestid;
 	int		no;
 	char		*name;
-	char		url[MAX_STRING_LEN];
+	char		url[MAX_STRING_LEN];	/* excessive length is required to support macros */
 	int		timeout;
 	char		posts[MAX_STRING_LEN];
 	char		required[HTTPSTEP_REQUIRED_LEN_MAX];
@@ -458,10 +487,24 @@ DB_HTTPTESTITEM
 	zbx_httpitem_type_t	type;
 };
 
+DB_ESCALATION
+{
+	zbx_uint64_t		escalationid;
+	zbx_uint64_t		actionid;
+	zbx_uint64_t		r_eventid;
+	int			esc_step;
+	zbx_escalation_status_t	status;
+	int			nextcheck;
+};
+
+#define DB_NODE "%s"
+#define DBnode_local(fieldid) DBnode(fieldid, CONFIG_NODEID)
+const char *DBnode(const char *fieldid, const int nodeid);
 
 int	DBping(void);
 
 void    DBconnect(int flag);
+void	DBinit();
 
 void    DBclose(void);
 void    DBvacuum(void);
@@ -488,23 +531,23 @@ void		DBbegin();
 void		DBcommit();
 void		DBrollback();
 
-zbx_uint64_t	DBget_maxid(char *table, char *field);
+const ZBX_TABLE	*DBget_table(const char *tablename);
+const ZBX_FIELD	*DBget_field(const ZBX_TABLE *table, const char *fieldname);
+#define DBget_maxid(table, field)	DBget_maxid_num(table, field, 1)
+zbx_uint64_t	DBget_maxid_num(char *table, char *field, int num);
 
-int	DBget_function_result(char **result,char *functionid);
-void	DBupdate_host_availability(zbx_uint64_t hostid,int available,int clock,char *error);
-int	DBupdate_item_status_to_notsupported(zbx_uint64_t itemid, char *error);
-int	DBadd_trend(zbx_uint64_t itemid, double value, int clock);
-int	DBadd_history(zbx_uint64_t itemid, double value, int clock);
-int	DBadd_history_log(zbx_uint64_t id, zbx_uint64_t itemid, char *value, int clock, int timestamp, char *source, int severity);
-int	DBadd_history_str(zbx_uint64_t itemid, char *value, int clock);
-int	DBadd_history_text(zbx_uint64_t itemid, char *value, int clock);
-int	DBadd_history_uint(zbx_uint64_t itemid, zbx_uint64_t value, int clock);
+int     DBget_function_result(char **result,char *functionid, char *error, int maxerrlen);
+void	DBupdate_host_availability(DB_ITEM *item, int available, int clock, const char *error);
+void	DBproxy_update_host_availability(DB_ITEM *item, int available, int clock);
+int	DBupdate_item_status_to_notsupported(DB_ITEM *item, int clock, const char *error);
 int	DBadd_service_alarm(zbx_uint64_t serviceid,int status,int clock);
-int	DBadd_alert(zbx_uint64_t actionid, zbx_uint64_t triggerid, zbx_uint64_t userid, zbx_uint64_t mediatypeid, char *sendto, char *subject, char *message);
+int	DBadd_alert(zbx_uint64_t actionid, zbx_uint64_t eventid, zbx_uint64_t userid, zbx_uint64_t mediatypeid, char *sendto, char *subject, char *message);
+int	DBstart_escalation(zbx_uint64_t actionid, zbx_uint64_t triggerid, zbx_uint64_t eventid);
+int	DBstop_escalation(zbx_uint64_t actionid, zbx_uint64_t triggerid, zbx_uint64_t eventid);
+int	DBremove_escalation(zbx_uint64_t escalationid);
 void	DBupdate_triggers_status_after_restart(void);
 int	DBget_prev_trigger_value(zbx_uint64_t triggerid);
-/*int	DBupdate_trigger_value(int triggerid,int value,int clock);*/
-int     DBupdate_trigger_value(DB_TRIGGER *trigger, int new_value, int now, char *reason);
+int     DBupdate_trigger_value(DB_TRIGGER *trigger, int new_value, int now, const char *reason);
 
 int	DBget_items_count(void);
 int	DBget_items_unsupported_count(void);
@@ -513,6 +556,7 @@ int	DBget_history_str_count(void);
 int	DBget_trends_count(void);
 int	DBget_triggers_count(void);
 int	DBget_queue_count(void);
+zbx_uint64_t DBget_proxy_lastaccess(const char *hostname);
 
 void    DBescape_string(const char *from, char *to, int maxlen);
 char*   DBdyn_escape_string(const char *str);
@@ -565,4 +609,21 @@ void	DBupdate_services(
 		zbx_uint64_t triggerid,
 		int status
 	);
+
+/* History related functions */
+int	DBadd_history(zbx_uint64_t itemid, double value, int clock);
+int	DBadd_history_log(zbx_uint64_t itemid, char *value, int clock, int timestamp, char *source, int severity, int lastlogsize);
+int	DBadd_history_str(zbx_uint64_t itemid, char *value, int clock);
+int	DBadd_history_text(zbx_uint64_t itemid, char *value, int clock);
+int	DBadd_history_uint(zbx_uint64_t itemid, zbx_uint64_t value, int clock);
+
+void	DBproxy_add_history(zbx_uint64_t itemid, double value, int clock);
+void	DBproxy_add_history_uint(zbx_uint64_t itemid, zbx_uint64_t value, int clock);
+void	DBproxy_add_history_str(zbx_uint64_t itemid, char *value, int clock);
+void	DBproxy_add_history_text(zbx_uint64_t itemid, char *value, int clock);
+void	DBproxy_add_history_log(zbx_uint64_t itemid, char *value, int clock, int timestamp, char *source, int severity, int lastlogsize);
+
+
+void	DBadd_condition_alloc(char **sql, int *sql_alloc, int *sql_offset, const char *fieldname, const zbx_uint64_t *values, const int num);
+
 #endif
