@@ -55,18 +55,21 @@ typedef struct zbx_result_s {
 	(res)->ui64 = (zbx_uint64_t)(val); \
 	}
 
+/* NOTE: always allocate new memory for val! DON'T USE STATIC OR STACK MEMORY!!! */
 #define SET_STR_RESULT(res, val) \
 	{ \
 	(res)->type |= AR_STRING; \
 	(res)->str = (char*)(val); \
 	} 
 
+/* NOTE: always allocate new memory for val! DON'T USE STATIC OR STACK MEMORY!!! */
 #define SET_TEXT_RESULT(res, val) \
 	{ \
 	(res)->type |= AR_TEXT; \
 	(res)->text = (char*)(val); \
 	} 
 
+/* NOTE: always allocate new memory for val! DON'T USE STATIC OR STACK MEMORY!!! */
 #define SET_MSG_RESULT(res, val) \
 	{ \
 	(res)->type |= AR_MESSAGE; \
@@ -139,6 +142,7 @@ typedef struct zbx_result_s {
 #define GET_MSG_RESULT(res)	((char**)get_result_value_by_type(res, AR_MESSAGE))
 
 void    *get_result_value_by_type(AGENT_RESULT *result, int require_type);
+void    *get_result_value_by_value_type(AGENT_RESULT *result, int value_type);
 
 extern int	CONFIG_ENABLE_REMOTE_COMMANDS;
 
@@ -159,6 +163,16 @@ typedef struct zbx_metric_type
 	char		*test_param;
 } ZBX_METRIC;
 
+/* collector */
+#define MAX_COLLECTOR_HISTORY 901 /* 15 min in seconds */
+#define ZBX_AVG1	0
+#define ZBX_AVG5	1
+#define ZBX_AVG15	2
+#define ZBX_AVGMAX	3
+
+int	get_diskstat(const char *devname, time_t *now,
+		zbx_uint64_t *r_oper, zbx_uint64_t *r_sect, zbx_uint64_t *w_oper, zbx_uint64_t *w_sect);
+
 /* flags for command */
 #define CF_USEUPARAM	1	/* use user param */
 
@@ -172,7 +186,7 @@ void	free_metrics(void);
 
 int	process(const char *in_command, unsigned flags, AGENT_RESULT *result);
 
-void    add_user_parameter(char *key,char *command);
+int	add_user_parameter(char *key, char *command);
 void	test_parameters(void);
 void	test_parameter(char* key);
 
