@@ -17,9 +17,8 @@
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/
 
-#include "config.h"
-
 #include "common.h"
+
 #include "sysinfo.h"
 
 #include "md5.h"
@@ -81,8 +80,9 @@ static int	SYSTEM_SWAP_PFREE(const char *cmd, const char *param, unsigned flags,
         init_result(result);
         init_result(&result_tmp);
 
-	if(SYSTEM_SWAP_TOTAL(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK)
-                return  SYSINFO_RET_FAIL;
+	if(SYSTEM_SWAP_TOTAL(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK ||
+		!(result_tmp.type & AR_UINT64))
+	                return  SYSINFO_RET_FAIL;
 	tot_val = result_tmp.ui64;
 
 	/* Check fot division by zero */
@@ -92,8 +92,9 @@ static int	SYSTEM_SWAP_PFREE(const char *cmd, const char *param, unsigned flags,
                 return  SYSINFO_RET_FAIL;
 	}
 
-	if(SYSTEM_SWAP_FREE(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK)
-                return  SYSINFO_RET_FAIL;
+	if(SYSTEM_SWAP_FREE(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK ||
+		!(result_tmp.type & AR_UINT64))
+                	return  SYSINFO_RET_FAIL;
 	free_val = result_tmp.ui64;
 
 	free_result(&result_tmp);
@@ -114,8 +115,9 @@ static int	SYSTEM_SWAP_PUSED(const char *cmd, const char *param, unsigned flags,
         init_result(result);
         init_result(&result_tmp);
 
-	if(SYSTEM_SWAP_TOTAL(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK)
-                return  SYSINFO_RET_FAIL;
+	if(SYSTEM_SWAP_TOTAL(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK ||
+		!(result_tmp.type & AR_UINT64))
+                	return  SYSINFO_RET_FAIL;
 	tot_val = result_tmp.ui64;
 
 	/* Check fot division by zero */
@@ -125,8 +127,9 @@ static int	SYSTEM_SWAP_PUSED(const char *cmd, const char *param, unsigned flags,
                 return  SYSINFO_RET_FAIL;
 	}
 
-	if(SYSTEM_SWAP_FREE(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK)
-                return  SYSINFO_RET_FAIL;
+	if(SYSTEM_SWAP_FREE(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK ||
+		!(result_tmp.type & AR_UINT64))
+                	return  SYSINFO_RET_FAIL;
 	free_val = result_tmp.ui64;
 
 	free_result(&result_tmp);
@@ -176,7 +179,7 @@ SWP_FNCLIST
         if(swapdev[0] == '\0')
 	{
 		/* default parameter */
-		sprintf(swapdev, "all");
+		zbx_snprintf(swapdev, sizeof(swapdev), "all");
 	}
 
 	if(strncmp(swapdev, "all", MAX_STRING_LEN))
@@ -192,7 +195,7 @@ SWP_FNCLIST
         if(mode[0] == '\0')
 	{
 		/* default parameter */
-		sprintf(mode, "free");
+		zbx_snprintf(mode, sizeof(mode), "free");
 	}
 
 	for(i=0; fl[i].mode!=0; i++)
@@ -241,35 +244,172 @@ int     OLD_SWAP(const char *cmd, const char *param, unsigned flags, AGENT_RESUL
         return ret;
 }
 
-static int 	get_swap_io(zbx_uint64_t *swapin, zbx_uint64_t *swapout)
+struct swap_stat_s {
+	zbx_uint64_t rio;
+	zbx_uint64_t rsect;
+	zbx_uint64_t rpag;
+	zbx_uint64_t wio;
+	zbx_uint64_t wsect;
+	zbx_uint64_t wpag;
+};
+
+#if defined(KERNEL_2_4)
+#	define INFO_FILE_NAME	"/proc/partitions"
+#	define PARSE(line)	if(sscanf(line,"%*d %*d %*d %s " \
+					ZBX_FS_UI64 " %*d " ZBX_FS_UI64 " %*d " \
+					ZBX_FS_UI64 " %*d " ZBX_FS_UI64 " %*d %*d %*d %*d", \
+				name, 			/* name */ \
+				&(result->rio), 	/* rio */ \
+				&(result->rsect),	/* rsect */ \
+				&(result->wio), 	/* rio */ \
+				&(result->wsect)	/* wsect */ \
+				) != 5) continue
+#else
+#	define INFO_FILE_NAME	"/proc/diskstats"
+#	define PARSE(line)	if(sscanf(line, "%*d %*d %s " \
+					ZBX_FS_UI64 " %*d " ZBX_FS_UI64 " %*d " \
+					ZBX_FS_UI64 " %*d " ZBX_FS_UI64 " %*d %*d %*d %*d", \
+				name, 			/* name */ \
+				&(result->rio), 	/* rio */ \
+				&(result->rsect),	/* rsect */ \
+				&(result->wio), 	/* wio */ \
+				&(result->wsect)	/* wsect */ \
+				) != 5)  \
+					if(sscanf(line,"%*d %*d %s " \
+						ZBX_FS_UI64 " " ZBX_FS_UI64 " " \
+						ZBX_FS_UI64 " " ZBX_FS_UI64, \
+					name, 			/* name */ \
+					&(result->rio), 	/* rio */ \
+					&(result->rsect),	/* rsect */ \
+					&(result->wio), 	/* wio */ \
+					&(result->wsect)	/* wsect */ \
+					) != 5) continue
+#endif
+
+static int get_swap_dev_stat(const char *interface, struct swap_stat_s *result)
 {
-	FILE	*f = NULL;
-	char	line[MAX_STRING_LEN];
-	char	name[20];
+	int ret = SYSINFO_RET_FAIL;
+	char line[MAX_STRING_LEN];
+
+	char name[MAX_STRING_LEN];
+
+	FILE *f;
+
+	assert(result);
+
+	if(NULL != (f = fopen(INFO_FILE_NAME,"r")))
+	{
+		while(fgets(line,MAX_STRING_LEN,f) != NULL)
+		{
+			PARSE(line);
+		
+			if(strncmp(name, interface, MAX_STRING_LEN) == 0)
+			{
+				ret = SYSINFO_RET_OK;
+				break;
+			}
+		}
+		fclose(f);
+	}
+
+	if(ret != SYSINFO_RET_OK)
+	{
+		result->rio	= 0;
+		result->rsect	= 0;
+		result->wio	= 0;
+		result->wsect	= 0;
+	}
+	return ret;
+}
+	
+static int	get_swap_pages(struct swap_stat_s *result)
+{
+	int ret = SYSINFO_RET_FAIL;
+	char line[MAX_STRING_LEN];
+	char name[MAX_STRING_LEN];
+
 	zbx_uint64_t
 		value1,
 		value2;
+	
+	FILE *f;
+
+	assert(result);
 
 	if(NULL != (f = fopen("/proc/stat","r")) )
 	{
 		while(fgets(line, sizeof(line), f))
 		{
-			if(sscanf(line, "%10s\t" ZBX_FS_UI64 "\t" ZBX_FS_UI64 "\n", name, &value1, &value2) != 3)
+			if(sscanf(line, "%10s " ZBX_FS_UI64 " " ZBX_FS_UI64, name, &value1, &value2) != 3)
 				continue;
 			
 			if(strcmp(name, "swap"))
 				continue;
 			
-			if(swapin)	*swapin  = value1;
-			if(swapout)	*swapout = value2;
-
-			fclose(f);
+			result->wpag	= value1;
+			result->rpag	= value2;
 			
-			return SYSINFO_RET_OK;
+			ret = SYSINFO_RET_OK;
+			break;
 		};
+		zbx_fclose(f);
+	}
+	
+	if(ret != SYSINFO_RET_OK)
+	{
+		result->wpag	= 0;
+		result->rpag	= 0;
+	}
+
+	return ret;
+}
+
+static int 	get_swap_stat(const char *interface, struct swap_stat_s *result)
+{
+	int ret = SYSINFO_RET_FAIL;
+	
+	struct swap_stat_s curr;
+	
+	FILE *f;
+
+	char line[MAX_STRING_LEN], *s;
+	
+	assert(result);
+
+	memset(result, 0, sizeof(struct swap_stat_s));
+
+	if(0 == strcmp(interface, "all"))
+	{
+		ret = get_swap_pages(result);
+		interface = NULL;
+	}
+
+	if(NULL != (f = fopen("/proc/swaps","r")) )
+	{
+		while (fgets(line, sizeof(line), f))
+		{
+			s = strchr(line,' ');
+			if (s && s != line && strncmp(line, "/dev/", 5) == 0)
+			{
+				*s = 0;
+
+				if(interface && 0 != strcmp(interface, line+5)) continue;
+				
+				if(SYSINFO_RET_OK == get_swap_dev_stat(line+5, &curr))
+				{
+					result->rio	+= curr.rio;
+					result->rsect	+= curr.rsect;
+					result->wio	+= curr.wio;
+					result->wsect	+= curr.wsect;
+					
+					ret = SYSINFO_RET_OK;
+				}
+			}
+		}
 		fclose(f);
 	}
-	return SYSINFO_RET_FAIL;
+
+	return ret;
 }
 
 int	SYSTEM_SWAP_IN(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
@@ -277,7 +417,8 @@ int	SYSTEM_SWAP_IN(const char *cmd, const char *param, unsigned flags, AGENT_RES
 	int		ret = SYSINFO_RET_FAIL;
 	char    	swapdev[10];
 	char    	mode[20];
-	zbx_uint64_t	value = 0;
+
+	struct swap_stat_s	ss;
 
 	assert(result);
 
@@ -296,12 +437,7 @@ int	SYSTEM_SWAP_IN(const char *cmd, const char *param, unsigned flags, AGENT_RES
 	if(swapdev[0] == '\0')
 	{
 		/* default parameter */
-		sprintf(swapdev, "all");
-	}
-
-	if(strcmp(swapdev, "all"))
-	{
-		return SYSINFO_RET_FAIL;
+		zbx_snprintf(swapdev, sizeof(swapdev), "all");
 	}
 
 	if(get_param(param, 2, mode, sizeof(mode)) != 0)
@@ -312,17 +448,32 @@ int	SYSTEM_SWAP_IN(const char *cmd, const char *param, unsigned flags, AGENT_RES
 	if(mode[0] == '\0')
 	{
 		/* default parameter */
-		sprintf(mode, "pages");
+		zbx_snprintf(mode, sizeof(mode), "pages");
 	}
 
-	if(strcmp(mode,"pages") != 0)
+	ret = get_swap_stat(swapdev, &ss);
+
+	if(ret == SYSINFO_RET_OK)
 	{
-		return SYSINFO_RET_FAIL;
-	}
-	
-	if( SYSINFO_RET_OK == (ret = get_swap_io(&value, NULL)) )
-	{
-		SET_UI64_RESULT(result, value);
+		if(strncmp(mode, "sectors", MAX_STRING_LEN)==0)
+		{
+			SET_UI64_RESULT(result, ss.wsect);
+			ret = SYSINFO_RET_OK;
+		}
+		else if(strncmp(mode, "count", MAX_STRING_LEN)==0)
+		{
+			SET_UI64_RESULT(result, ss.wio);
+			ret = SYSINFO_RET_OK;
+		}
+		else if(strncmp(mode, "pages", MAX_STRING_LEN)==0 && strcmp(swapdev, "all")==0)
+		{
+			SET_UI64_RESULT(result, ss.wpag);
+			ret = SYSINFO_RET_OK;
+		}
+		else
+		{
+			ret = SYSINFO_RET_FAIL;
+		}
 	}
 
 	return ret;
@@ -333,7 +484,8 @@ int	SYSTEM_SWAP_OUT(const char *cmd, const char *param, unsigned flags, AGENT_RE
 	int		ret = SYSINFO_RET_FAIL;
 	char    	swapdev[10];
 	char    	mode[20];
-	zbx_uint64_t	value = 0;
+
+	struct swap_stat_s	ss;
 
 	assert(result);
 
@@ -352,12 +504,7 @@ int	SYSTEM_SWAP_OUT(const char *cmd, const char *param, unsigned flags, AGENT_RE
 	if(swapdev[0] == '\0')
 	{
 		/* default parameter */
-		sprintf(swapdev, "all");
-	}
-
-	if(strcmp(swapdev, "all"))
-	{
-		return SYSINFO_RET_FAIL;
+		zbx_snprintf(swapdev, sizeof(swapdev), "all");
 	}
 
 	if(get_param(param, 2, mode, sizeof(mode)) != 0)
@@ -368,17 +515,32 @@ int	SYSTEM_SWAP_OUT(const char *cmd, const char *param, unsigned flags, AGENT_RE
 	if(mode[0] == '\0')
 	{
 		/* default parameter */
-		sprintf(mode, "pages");
+		zbx_snprintf(mode, sizeof(mode), "pages");
 	}
 
-	if(strcmp(mode,"pages") != 0)
+	ret = get_swap_stat(swapdev, &ss);
+
+	if(ret == SYSINFO_RET_OK)
 	{
-		return SYSINFO_RET_FAIL;
-	}
-	
-	if( SYSINFO_RET_OK == (ret = get_swap_io(NULL, &value)) )
-	{
-		SET_UI64_RESULT(result, value);
+		if(strncmp(mode, "sectors", MAX_STRING_LEN)==0)
+		{
+			SET_UI64_RESULT(result, ss.rsect);
+			ret = SYSINFO_RET_OK;
+		}
+		else if(strncmp(mode, "count", MAX_STRING_LEN)==0)
+		{
+			SET_UI64_RESULT(result, ss.rio);
+			ret = SYSINFO_RET_OK;
+		}
+		else if(strncmp(mode, "pages", MAX_STRING_LEN)==0 && strcmp(swapdev, "all")==0)
+		{
+			SET_UI64_RESULT(result, ss.rpag);
+			ret = SYSINFO_RET_OK;
+		}
+		else
+		{
+			ret = SYSINFO_RET_FAIL;
+		}
 	}
 
 	return ret;
