@@ -75,63 +75,60 @@ void	add_metric(ZBX_METRIC *new)
 	}
 }
 
-void	add_user_parameter(char *key,char *command)
+int	add_user_parameter(char *key, char *command)
 {
-	register int i;
-	char	usr_cmd[MAX_STRING_LEN];
-	char	usr_param[MAX_STRING_LEN];
+	register int	i;
+	char		usr_cmd[MAX_STRING_LEN];
+	char		usr_param[MAX_STRING_LEN];
 	unsigned	flag = 0;
 	
-	i = parse_command(key, usr_cmd, MAX_STRING_LEN, usr_param, MAX_STRING_LEN);
-	if(i == 0)
+	if (0 == (i = parse_command(key, usr_cmd, MAX_STRING_LEN, usr_param, MAX_STRING_LEN)))
 	{
 		zabbix_log( LOG_LEVEL_WARNING, "Can't add user specifed key \"%s\". Can't parse key!", key);
-		return;
+		return FAIL;
 	} 
-	else if(i == 2) /* with specifed parameters */
+	else if (2 == i)				/* with specifed parameters */
 	{
-		if(strcmp(usr_param,"*")){ /* must be '*' parameters */
+		if (0 != strcmp(usr_param, "*"))	/* must be '*' parameters */
+		{
 			zabbix_log(LOG_LEVEL_WARNING, "Can't add user specifed key \"%s\". Incorrect key!", key);
-			return;
+			return FAIL;
 		}
 		flag |= CF_USEUPARAM;
 	}
 
-	for(i=0;;i++)
+	for (i = 0; ; i++)
 	{
 		/* Add new parameters */
-		if( commands[i].key == 0)
+		if (0 == commands[i].key)
 		{
 			commands[i].key = strdup(usr_cmd);
 			commands[i].flags = flag;
 			commands[i].function = &EXECUTE_STR;
 			commands[i].main_param = strdup(command);
 			commands[i].test_param = 0;
-			commands = zbx_realloc(commands,(i+2)*sizeof(ZBX_METRIC));
-			commands[i+1].key=NULL;
-
+			commands = zbx_realloc(commands, (i + 2) * sizeof(ZBX_METRIC));
+			commands[i + 1].key = NULL;
 			break;
 		}
 		
 		/* Replace existing parameters */
-		if(strcmp(commands[i].key, key) == 0)
+		if (0 == strcmp(commands[i].key, key))
 		{
-			if(commands[i].key)
-				free(commands[i].key);
-			if(commands[i].main_param)	
-				free(commands[i].main_param);
-			if(commands[i].test_param)	
-				free(commands[i].test_param);
+			if (commands[i].main_param)	
+				zbx_free(commands[i].main_param);
+			if (commands[i].test_param)	
+				zbx_free(commands[i].test_param);
 
-			commands[i].key = strdup(key);
 			commands[i].flags = flag;
 			commands[i].function = &EXECUTE_STR;
 			commands[i].main_param = strdup(command);
 			commands[i].test_param = 0;
-
 			break;
 		}
 	}
+
+	return SUCCEED;
 }
 
 void	init_metrics(void)
@@ -609,8 +606,6 @@ int	set_result_type(AGENT_RESULT *result, int value_type, char *c)
 
 static zbx_uint64_t* get_result_ui64_value(AGENT_RESULT *result)
 {
-	zbx_uint64_t tmp;
-
 	assert(result);
 
 	if(ISSET_UI64(result))
@@ -623,13 +618,17 @@ static zbx_uint64_t* get_result_ui64_value(AGENT_RESULT *result)
 	}
 	else if(ISSET_STR(result))
 	{
-		if(EOF != sscanf(result->str, ZBX_FS_UI64, &tmp))
-			SET_UI64_RESULT(result, tmp);
+		if (SUCCEED == is_uint(result->str))
+		{
+			SET_UI64_RESULT(result, zbx_atoui64(result->str));
+		}
 	}
 	else if(ISSET_TEXT(result))
 	{
-		if(EOF != sscanf(result->text, ZBX_FS_UI64, &tmp))
-			SET_UI64_RESULT(result, tmp);
+		if (SUCCEED == is_uint(result->text))
+		{
+			SET_UI64_RESULT(result, zbx_atoui64(result->text));
+		}
 	}
 	/* skip AR_MESSAGE - it is information field */
 
@@ -643,8 +642,6 @@ static zbx_uint64_t* get_result_ui64_value(AGENT_RESULT *result)
 
 static double* get_result_dbl_value(AGENT_RESULT *result)
 {
-	double tmp;
-
 	assert(result);
 
 	if(ISSET_DBL(result))
@@ -657,13 +654,17 @@ static double* get_result_dbl_value(AGENT_RESULT *result)
 	}
 	else if(ISSET_STR(result))
 	{
-		if(EOF != sscanf(result->str, ZBX_FS_DBL, &tmp))
-			SET_DBL_RESULT(result, tmp);
+		if (SUCCEED == is_double(result->str))
+		{
+			SET_DBL_RESULT(result, atof(result->str));
+		}
 	}
 	else if(ISSET_TEXT(result))
 	{
-		if(EOF != sscanf(result->text, ZBX_FS_DBL, &tmp))
-			SET_DBL_RESULT(result, tmp);
+		if (SUCCEED == is_double(result->text))
+		{
+			SET_DBL_RESULT(result, atof(result->text));
+		}
 	}
 	/* skip AR_MESSAGE - it is information field */
 
@@ -791,3 +792,37 @@ void	*get_result_value_by_type(AGENT_RESULT *result, int require_type)
 	}
 	return NULL;
 }
+
+/******************************************************************************
+ *                                                                            *
+ * Function: get_result_value_by_value_type                                   *
+ *                                                                            *
+ * Purpose: return value of result in special type                            *
+ *          if value missed convert existed value to requested type           *
+ *                                                                            *
+ * Return value:                                                              *
+ *         NULL - if value are missed or can't be converted                   *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+void	*get_result_value_by_value_type(AGENT_RESULT *result, int value_type)
+{
+	assert(result);
+
+	switch (value_type)
+	{
+		case ITEM_VALUE_TYPE_FLOAT:
+			return (void *)get_result_dbl_value(result);
+		case ITEM_VALUE_TYPE_STR:
+		case ITEM_VALUE_TYPE_LOG:
+			return (void *)get_result_str_value(result);
+		case ITEM_VALUE_TYPE_UINT64:
+			return (void *)get_result_ui64_value(result);
+		case ITEM_VALUE_TYPE_TEXT:
+			return (void *)get_result_text_value(result);
+	}
+	return NULL;
+}
