@@ -69,91 +69,66 @@ int     OLD_CPU(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 
 int	SYSTEM_CPU_UTIL(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
+	char	tmp[MAX_STRING_LEN], mode[MAX_STRING_LEN];
+	int	cpu_num = 0;
 
-	char cpuname[MAX_STRING_LEN];
-	char type[MAX_STRING_LEN];
-	char mode[MAX_STRING_LEN];
-
-	int cpu_num = 0;
-
-	if(num_param(param) > 3)
-	{
+	if (num_param(param) > 3)
 		return SYSINFO_RET_FAIL;
+
+	if (0 != get_param(param, 1, tmp, sizeof(tmp)))
+		*tmp = '\0';
+
+	/* default parameter */
+	if (*tmp == '\0')
+		zbx_snprintf(tmp, sizeof(tmp), "all");
+
+	if (0 == strcmp(tmp, "all"))
+		cpu_num = 0;
+	else
+	{
+		cpu_num = atoi(tmp) + 1;
+		if (cpu_num < 1 || cpu_num > collector->cpus.count)
+			return SYSINFO_RET_FAIL;
 	}
 
-	if(get_param(param, 1, cpuname, sizeof(cpuname)) != 0)
-	{
-		cpuname[0] = '\0';
-	}
-	if(cpuname[0] == '\0')
-	{
-		/* default parameter */
-		zbx_snprintf(cpuname, sizeof(cpuname), "all");
-	}
+	if (0 != get_param(param, 2, tmp, sizeof(tmp)))
+		*tmp = '\0';
 
-	if(get_param(param, 2, type, sizeof(type)) != 0)
-	{
-		type[0] = '\0';
-	}
-	if(type[0] == '\0')
-	{
-		/* default parameter */
-		zbx_snprintf(type, sizeof(type), "system");
-	}
-	if(strncmp(type, "system", sizeof(type)))
-	{	/* only 'system' parameter supported */
+	/* default parameter */
+	if (*tmp == '\0')
+		zbx_snprintf(tmp, sizeof(tmp), "system");
+
+	/* only 'system' parameter supported */
+	if (0 != strcmp(tmp, "system"))
 		return SYSINFO_RET_FAIL;
-	}
 
-	if(get_param(param, 3, mode, sizeof(mode)) != 0)
-	{
-		mode[0] = '\0';
-	}
+	if (0 != get_param(param, 3, mode, sizeof(mode)))
+		*mode = '\0';
 
-	if(mode[0] == '\0')
-	{
-		/* default parameter */
+	/* default parameter */
+	if (*mode == '\0')
 		zbx_snprintf(mode, sizeof(mode), "avg1");
-	}
 	
-	if ( !CPU_COLLECTOR_STARTED(collector) )
+	if (!CPU_COLLECTOR_STARTED(collector))
 	{
 		SET_MSG_RESULT(result, strdup("Collector is not started!"));
 		return SYSINFO_RET_OK;
 	}
 
-	if(strcmp(cpuname,"all") == 0)
-	{
-		cpu_num = 0;
-	}
-	else
-	{
-		cpu_num = atoi(cpuname)+1;
-		if ((cpu_num < 1) || (cpu_num > collector->cpus.count))
-			return SYSINFO_RET_FAIL;
-	}
-
-	if(strcmp(type,"system"))
-	{
-		return SYSINFO_RET_FAIL;
-	}
-
-	if(strcmp(mode,"avg1") == 0)
+	if (0 == strcmp(mode,"avg1"))
 	{
 		SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].util1);
 	}
-	else	if(strcmp(mode,"avg5") == 0)
+	else if(0 == strcmp(mode,"avg5"))
 	{
 		SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].util5);
 	}
-	else	if(strcmp(mode,"avg15") == 0)
+	else if(0 == strcmp(mode,"avg15"))
 	{
 		SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].util15);
 	}
 	else
-	{
 		return SYSINFO_RET_FAIL;
-	}
 
 	return SYSINFO_RET_OK;
 }
