@@ -27,6 +27,7 @@
 #include "eventlog.h"
 #include "comms.h"
 #include "threads.h"
+#include "zbxjson.h"
 
 #if defined(ZABBIX_SERVICE)
 #	include "service.h"
@@ -35,6 +36,7 @@
 #endif /* ZABBIX_DAEMON */
 
 static ZBX_ACTIVE_METRIC *active_metrics = NULL;
+static ZBX_ACTIVE_BUFFER buffer;
 
 static void	init_active_metrics()
 {
@@ -113,7 +115,7 @@ static int	get_min_nextcheck()
 	return min;
 }
 
-static void	add_check(char *key, int refresh, long lastlogsize)
+static void	add_check(const char *key, const char *key_orig, int refresh, long lastlogsize)
 {
 	int i;
 
@@ -138,6 +140,7 @@ static void	add_check(char *key, int refresh, long lastlogsize)
 
 	/* add new metric */
 	active_metrics[i].key		= strdup(key);
+	active_metrics[i].key_orig	= strdup(key_orig);
 	active_metrics[i].refresh	= refresh;
 	active_metrics[i].nextcheck	= 0;
 	active_metrics[i].status	= ITEM_STATUS_ACTIVE;
@@ -164,7 +167,7 @@ static void	add_check(char *key, int refresh, long lastlogsize)
  * Return value: returns SUCCEED on succesfull parsing,                       *
  *               FAIL on an incoorrect format of string                       *
  *                                                                            *
- * Author: Eugene Grigorjev                                                   *
+ * Author: Eugene Grigorjev, Alexei Vladishev (new json protocol)             *
  *                                                                            *
  * Comments:                                                                  *
  *    String reprents as "ZBX_EOF" termination list                           *
@@ -175,64 +178,106 @@ static void	add_check(char *key, int refresh, long lastlogsize)
  ******************************************************************************/
 static int	parse_list_of_checks(char *str)
 {
-	char	*p, *pstrend, *refresh, *lastlogsize;
+	const char	*p;
+	char	key[MAX_STRING_LEN], key_orig[MAX_STRING_LEN], delay[MAX_STRING_LEN], lastlogsize[MAX_STRING_LEN];
+	char	result[MAX_STRING_LEN];
+	int	ret = SUCCEED;
+
+	struct	zbx_json_parse jp;
+	struct	zbx_json_parse   jp_data, jp_row;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In parse_list_of_checks() [%s]",
 		str);
 
 	disable_all_metrics();
 
-	while (NULL != str) {
-		if (NULL != (pstrend = strchr(str,'\n')))
-			*pstrend = '\0'; /* prepare line */
-
-		zabbix_log(LOG_LEVEL_DEBUG, "Parsed [%s]", str);
-
-		if (0 == strcmp(str, "ZBX_EOF"))
-			break;
-
-		refresh = NULL; 
-		lastlogsize = NULL;
-
-		/* parse string from end of line */
-		/* line format "key:refresh:lastlogsize" */
-
-		p = (NULL != pstrend) ? pstrend : str + strlen(str);
-
-		/* Lastlogsize */
-		for (; p != str; p--) {
-			if (*p == ':') {
-				*p = '\0';
-
-				lastlogsize = p + 1;
-				break;
-			}
-		}
-
-		/* Refresh */
-		for (; p != str; p--) {
-			if (*p == ':') {
-				*p = '\0';
-
-				refresh = p + 1;
-				break;
-			}
-		}
-
-		if (str && refresh && lastlogsize)
-			add_check(str, atoi(refresh), atoi(lastlogsize));
-
-		if (pstrend == NULL)
-			break;
-
-		str = pstrend + 1;
+	if(SUCCEED == ret && SUCCEED != zbx_json_open(str, &jp))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "Can't open jason object");
+		ret = FAIL;
 	}
+
+	if(SUCCEED == ret && SUCCEED != zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_RESPONSE, result, sizeof(result)))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "%s",
+			zbx_json_strerror());
+		ret = FAIL;
+	}
+
+	if(SUCCEED == ret && 0 != strcmp(result,ZBX_PROTO_VALUE_SUCCESS))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "Unsucesfull response received from server");
+		ret = FAIL;
+	}
+
+	if(SUCCEED == ret && NULL == (p = zbx_json_pair_by_name(&jp, ZBX_PROTO_TAG_DATA)))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "Can't find \"%s\" tag",
+			ZBX_PROTO_TAG_DATA);
+		ret = FAIL;
+	}
+
+	if(SUCCEED == ret && FAIL == zbx_json_brackets_open(p, &jp_data))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "Can't proceed jason request. %s",
+				zbx_json_strerror());
+		ret = FAIL;
+	}
+
+	if(SUCCEED == ret)
+	{
+	 	p = NULL;
+		while (SUCCEED == ret && NULL != (p = zbx_json_next(&jp_data, p)))
+		{
+/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]} 
+ *                                      ^------------------------------^
+ */ 			if (FAIL == (ret = zbx_json_brackets_open(p, &jp_row)))
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "%s",
+					zbx_json_strerror());
+				ret = FAIL;
+				break;
+			}
+
+			*delay = '\0';
+			*key = '\0';
+			*lastlogsize = '\0';
+
+			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_KEY, key, sizeof(key)))
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
+					ZBX_PROTO_TAG_KEY);
+				continue;
+			}
+
+			if (SUCCEED != zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_KEY_ORIG, key_orig, sizeof(key_orig)) || *key_orig == '\0')
+				zbx_strlcpy(key_orig, key, sizeof(key_orig));
+
+			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_DELAY, delay, sizeof(delay)))
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
+					ZBX_PROTO_TAG_DELAY);
+				continue;
+			}
+
+			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_LOGLASTSIZE, lastlogsize, sizeof(lastlogsize)))
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
+					ZBX_PROTO_TAG_LOGLASTSIZE);
+				continue;
+			}
+
+			if (*key && *delay && *lastlogsize)
+				add_check(key, key_orig, atoi(delay), atoi(lastlogsize));
+		}
+	}
+
 	return SUCCEED;
 }
 
 /******************************************************************************
  *                                                                            *
- * Function: get_active_checks                                                *
+ * Function: refresh_active_checks                                            *
  *                                                                            *
  * Purpose: Retrive from ZABBIX server list of active checks                  *
  *                                                                            *
@@ -242,12 +287,12 @@ static int	parse_list_of_checks(char *str)
  * Return value: returns SUCCEED on succesfull parsing,                       *
  *               FAIL on other cases                                          *
  *                                                                            *
- * Author: Eugene Grigorjev                                                   *
+ * Author: Eugene Grigorjev, Alexei Vladishev (new json protocol)             *
  *                                                                            *
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int	get_active_checks(
+static int	refresh_active_checks(
 	const char		*host, 
 	unsigned short	port
 	)
@@ -255,24 +300,29 @@ static int	get_active_checks(
 
 	zbx_sock_t	s;
 
-	char
-		*buf,
-		packet[MAX_BUF_LEN];
+	char	*buf;
 
 	int	ret;
 
-	zabbix_log( LOG_LEVEL_DEBUG, "get_active_checks('%s',%u)", host, port);
+	struct zbx_json json;
 
-	if (SUCCEED == (ret = zbx_tcp_connect(&s, host, port, CONFIG_TIMEOUT))) {
-		zbx_snprintf(packet, sizeof(packet), "%s\n%s\n","ZBX_GET_ACTIVE_CHECKS", CONFIG_HOSTNAME);
-		zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]", packet);
+	zabbix_log( LOG_LEVEL_DEBUG, "refresh_active_checks('%s',%u)", host, port);
 
-		if( SUCCEED == (ret = zbx_tcp_send(&s, packet)) )
+	zbx_json_init(&json, 8*1024);
+
+	zbx_json_addstring(&json, ZBX_PROTO_TAG_REQUEST, ZBX_PROTO_VALUE_GET_ACTIVE_CHECKS, ZBX_JSON_TYPE_STRING);
+	zbx_json_addstring(&json, ZBX_PROTO_TAG_HOST, CONFIG_HOSTNAME, ZBX_JSON_TYPE_STRING);
+
+	if (SUCCEED == (ret = zbx_tcp_connect(&s, CONFIG_SOURCE_IP, host, port, CONFIG_TIMEOUT))) {
+		zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]", json.buffer);
+
+		if( SUCCEED == (ret = zbx_tcp_send(&s, json.buffer)) )
 		{
 			zabbix_log(LOG_LEVEL_DEBUG, "Before read");
 
 			if( SUCCEED == (ret = zbx_tcp_recv_ext(&s, &buf, ZBX_TCP_READ_UNTIL_CLOSE)) )
 			{
+				zabbix_log(LOG_LEVEL_DEBUG, "Got [%s]", buf);
 				parse_list_of_checks(buf);
 			}
 		}
@@ -282,16 +332,201 @@ static int	get_active_checks(
 	if( FAIL == ret )
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "Get active checks error: %s", zbx_tcp_strerror());
-	}	
+	}
+
+	zbx_json_free(&json);
+
 	return ret;
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: check_response                                                   *
+ *                                                                            *
+ * Purpose: Check if json response is SUCCEED                                 *
+ *                                                                            *
+ * Parameters: result SUCCEED or FAIL                                         *
+ *                                                                            *
+ * Return value:  SUCCEED - processed successfully                            *
+ *                FAIL - an error occured                                     *
+ *                                                                            *
+ * Author: Alexei Vladishev                                                   *
+ *                                                                            *
+ * Comments: zabbix_sender has exactly the same function!                     *
+ *                                                                            *
+ ******************************************************************************/
+static int	check_response(char *response)
+{
+	struct 		zbx_json_parse jp;
+	char		value[MAX_STRING_LEN];
+	char		info[MAX_STRING_LEN];
+
+	int	ret = SUCCEED;
+
+	zabbix_log( LOG_LEVEL_DEBUG, "In check_response(%s)", response);
+
+	ret = zbx_json_open(response, &jp);
+
+	if (SUCCEED == ret)
+	{
+		ret = zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_RESPONSE,value, sizeof(value));
+	}
+
+	if(SUCCEED == ret)
+	{
+		if(strcmp(value, ZBX_PROTO_VALUE_SUCCESS) != 0)
+		{
+			ret = FAIL;
+		}
+	}
+
+	if (SUCCEED == ret)
+	{
+		if(SUCCEED == zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_INFO, info, sizeof(info)))
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "Info from server: %s",
+				info);
+		}
+	}
+
+	return ret;
+}
 
 /******************************************************************************
  *                                                                            *
- * Function: send_value                                                       *
+ * Function: send_buffer                                                      *
  *                                                                            *
- * Purpose: Send value of specified key to ZABBIX server                      *
+ * Purpose: Send value stgored in the buffer to ZABBIX server                 *
+ *                                                                            *
+ * Parameters: host - IP or Hostname of ZABBIX server                         *
+ *             port - port number                                             *
+ *                                                                            *
+ * Return value: returns SUCCEED on succesfull parsing,                       *
+ *               FAIL on other cases                                          *
+ *                                                                            *
+ * Author: Alexei Vladishev                                                   *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+static int	send_buffer(
+		const char		*host,
+		unsigned short	port
+	)
+{
+	zbx_sock_t	s;
+	char		*buf = NULL;
+	int		ret = SUCCEED;
+	struct zbx_json json;
+	int		i;
+	static int	lastsent = 0;
+	int		now;
+
+	zabbix_log( LOG_LEVEL_DEBUG, "In send_buffer('%s','%d')",
+		host, port);
+
+	zabbix_log( LOG_LEVEL_DEBUG, "Values in the buffer %d Max %d",
+		buffer.count,
+		CONFIG_BUFFER_SIZE);
+
+	now = (int)time(NULL);
+	if(buffer.count < CONFIG_BUFFER_SIZE && now-lastsent < CONFIG_BUFFER_SEND)
+	{
+		zabbix_log( LOG_LEVEL_DEBUG, "Will not send now. Now %d lastsent %d < %d",
+			now,
+			lastsent,
+			CONFIG_BUFFER_SEND);
+		return ret;
+	}
+
+	if(buffer.count < 1)
+	{
+		return ret;
+	}
+
+	zbx_json_init(&json, 8*1024);
+
+	zbx_json_addstring(&json, ZBX_PROTO_TAG_REQUEST, ZBX_PROTO_VALUE_AGENT_DATA, ZBX_JSON_TYPE_STRING);
+
+	zbx_json_addarray(&json, ZBX_PROTO_TAG_DATA);
+
+	for(i=0;i<buffer.count;i++)
+	{
+		zbx_json_addobject(&json, NULL);
+		zbx_json_addstring(&json, ZBX_PROTO_TAG_HOST, buffer.data[i].host, ZBX_JSON_TYPE_STRING);
+		zbx_json_addstring(&json, ZBX_PROTO_TAG_KEY, buffer.data[i].key, ZBX_JSON_TYPE_STRING);
+		zbx_json_addstring(&json, ZBX_PROTO_TAG_VALUE, buffer.data[i].value, ZBX_JSON_TYPE_STRING);
+		if (buffer.data[i].lastlogsize)
+			zbx_json_adduint64(&json, ZBX_PROTO_TAG_LOGLASTSIZE, buffer.data[i].lastlogsize);
+		if (buffer.data[i].timestamp)
+			zbx_json_adduint64(&json, ZBX_PROTO_TAG_LOGTIMESTAMP, buffer.data[i].timestamp);
+		if (buffer.data[i].source)
+			zbx_json_addstring(&json, ZBX_PROTO_TAG_LOGSOURCE, buffer.data[i].source, ZBX_JSON_TYPE_STRING);
+		if (buffer.data[i].severity)
+			zbx_json_adduint64(&json, ZBX_PROTO_TAG_LOGSEVERITY, buffer.data[i].severity);
+		zbx_json_adduint64(&json, ZBX_PROTO_TAG_CLOCK, buffer.data[i].clock);
+		zbx_json_close(&json);
+	}
+
+	zbx_json_close(&json);
+
+	zbx_json_adduint64(&json, ZBX_PROTO_TAG_CLOCK, (int)time(NULL));
+
+	if (SUCCEED == (ret = zbx_tcp_connect(&s, CONFIG_SOURCE_IP, host, port, MIN(buffer.count*CONFIG_TIMEOUT, 60)))) {
+
+		zabbix_log(LOG_LEVEL_DEBUG, "JSON before sending [%s]",
+			json.buffer);
+
+		ret = zbx_tcp_send(&s, json.buffer);
+
+		if( SUCCEED == ret )
+		{
+			if( SUCCEED == (ret = zbx_tcp_recv(&s, &buf)) )
+			{
+				zabbix_log( LOG_LEVEL_DEBUG, "JSON back [%s]",
+					buf);
+				if( !buf || check_response(buf) != SUCCEED )
+				{
+					zabbix_log( LOG_LEVEL_WARNING, "NOT OK");
+				}
+				else
+				{
+					zabbix_log( LOG_LEVEL_WARNING, "OK");
+				}
+			} else
+				zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [recv] %s", zbx_tcp_strerror());
+		} else
+			zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [send] %s", zbx_tcp_strerror());
+
+		zbx_tcp_close(&s);
+	} else
+		zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [connect] %s", zbx_tcp_strerror());
+
+	zbx_json_free(&json);
+
+	if(SUCCEED == ret)
+	{
+		/* free buffer */
+		for(i=0;i<buffer.count;i++)
+		{
+			if(buffer.data[i].host != NULL)		zbx_free(buffer.data[i].host);
+			if(buffer.data[i].key != NULL)		zbx_free(buffer.data[i].key);
+			if(buffer.data[i].value != NULL)	zbx_free(buffer.data[i].value);
+			if(buffer.data[i].source != NULL)	zbx_free(buffer.data[i].source);
+		}
+		buffer.count = 0;
+	}
+
+	if(SUCCEED == ret)	lastsent = now;
+
+	return ret;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Function: process_value                                                    *
+ *                                                                            *
+ * Purpose: Buffer new value or send the whole buffer to the server           *
  *                                                                            *
  * Parameters: host - IP or Hostname of ZABBIX server                         *
  *             port - port of ZABBIX server                                   *
@@ -306,62 +541,85 @@ static int	get_active_checks(
  * Return value: returns SUCCEED on succesfull parsing,                       *
  *               FAIL on other cases                                          *
  *                                                                            *
- * Author: Eugene Grigorjev                                                   *
+ * Author: Alexei Vladishev                                                   *
  *                                                                            *
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int	send_value(
-		const char		*host,
+static int	process_value(
+		const char		*server,
 		unsigned short	port,
-		const char		*hostname,
+		const char		*host,
 		const char		*key,
 		const char		*value,
 		long			*lastlogsize,
 		unsigned long	*timestamp,
 		const char		*source, 
 		unsigned short	*severity
-	)
+)
 {
-	zbx_sock_t	s;
-	char		*buf = NULL,
-			*request = NULL;
-	int		ret;
+	ZBX_ACTIVE_BUFFER_ELEMENT	*el;
+	int				ret = SUCCEED;
 
-	if (SUCCEED == (ret = zbx_tcp_connect(&s, host, port, CONFIG_TIMEOUT))) {
-		request = comms_create_request(hostname, key, value, lastlogsize, timestamp, source, severity);
+	zabbix_log( LOG_LEVEL_DEBUG, "In process_value('%s','%s','%s')",
+		host, key, value);
 
-		zabbix_log(LOG_LEVEL_DEBUG, "XML before sending [%s]",request);
+	send_buffer(server,port);
 
-		ret = zbx_tcp_send(&s, request);
+	/* Called first time, allocate memory */
+	if(NULL == buffer.data)
+	{
+		zabbix_log( LOG_LEVEL_DEBUG, "Buffer: first allocation for %d elements",
+			CONFIG_BUFFER_SIZE);
+		buffer.data = zbx_malloc(buffer.data, CONFIG_BUFFER_SIZE*sizeof(ZBX_ACTIVE_BUFFER_ELEMENT));
+		memset(buffer.data, 0, CONFIG_BUFFER_SIZE*sizeof(ZBX_ACTIVE_BUFFER_ELEMENT));
+		buffer.count = 0;
+	}
 
-		zbx_free(request);
+	if(buffer.count < CONFIG_BUFFER_SIZE)
+	{
+		zabbix_log( LOG_LEVEL_DEBUG, "Buffer: new element %d", buffer.count);
 
-		if( SUCCEED == ret )
+		el = &buffer.data[buffer.count];
+		buffer.count++;
+	}
+	else
+	{
+		zabbix_log( LOG_LEVEL_DEBUG, "Buffer full: new element %d", buffer.count);
+
+		if(buffer.data[0].host != NULL)	zbx_free(buffer.data[0].host);
+		if(buffer.data[0].key != NULL)	zbx_free(buffer.data[0].key);
+		if(buffer.data[0].value != NULL)	zbx_free(buffer.data[0].value);
+		if(buffer.data[0].source != NULL)	zbx_free(buffer.data[0].source);
+		memmove(&buffer.data[0],&buffer.data[1], (CONFIG_BUFFER_SIZE-1)*sizeof(ZBX_ACTIVE_BUFFER_ELEMENT));
+
+		el = &buffer.data[CONFIG_BUFFER_SIZE-1];
+	}
+
+	memset(el, 0, sizeof(ZBX_ACTIVE_BUFFER_ELEMENT));
+	el->host	= strdup(host);
+	el->key		= strdup(key);
+	el->value	= strdup(value);
+	if (source)
+		el->source	= strdup(source);
+	if (severity)
+		el->severity	= *severity;
+	if (lastlogsize)
+		el->lastlogsize	= *lastlogsize;
+	if (timestamp)
+		el->timestamp	= *timestamp;
+	el->clock	= (int)time(NULL);
+
+/*	zabbix_log(LOG_LEVEL_DEBUG, "BUFFER");
+		for(i=0;i<buffer.count;i++)
 		{
-			if( SUCCEED == (ret = zbx_tcp_recv(&s, &buf)) )
-			{
-				/* !!! REMOVE '\n' AT THE AND (always must be present) !!! */
-				zbx_rtrim(buf, "\r\n\0");
-				if(strcmp(buf,"OK") == 0)
-				{
-					zabbix_log( LOG_LEVEL_DEBUG, "OK");
-				}
-				else
-				{
-					zabbix_log( LOG_LEVEL_DEBUG, "NOT OK [%s:%s] [%s]", host, key, buf);
-				}
-			} else
-				zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [recv] %s", zbx_tcp_strerror());
-		} else
-			zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [send] %s", zbx_tcp_strerror());
-		zbx_tcp_close(&s);
-	} else
-		zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [connect] %s", zbx_tcp_strerror());
+			zabbix_log(LOG_LEVEL_DEBUG, " Host %s Key %s Values %s", buffer.data[i].host, buffer.data[i].key, buffer.data[i].value);
+		}*/
 
 	return ret;
 }
 
+
 static void	process_active_checks(char *server, unsigned short port)
 {
 	register int	i, s_count, p_count;
@@ -413,11 +671,11 @@ static void	process_active_checks(char *server, unsigned short port)
 						break;
 
 					if ('\0' == *pattern || NULL != zbx_regexp_match(value, pattern, NULL)) {
-						send_err = send_value(
+						send_err = process_value(
 									server,
 									port,
 									CONFIG_HOSTNAME,
-									active_metrics[i].key,
+									active_metrics[i].key_orig,
 									value,
 									&lastlogsize,
 									NULL,
@@ -448,11 +706,11 @@ static void	process_active_checks(char *server, unsigned short port)
 					zabbix_log( LOG_LEVEL_WARNING, "Active check [%s] is not supported. Disabled.",
 						active_metrics[i].key);
 
-					send_err = send_value(
+					send_err = process_value(
 								server,
 								port,
 								CONFIG_HOSTNAME,
-								active_metrics[i].key,
+								active_metrics[i].key_orig,
 								"ZBX_NOTSUPPORTED",
 								&active_metrics[i].lastlogsize,
 								NULL,
@@ -489,11 +747,11 @@ static void	process_active_checks(char *server, unsigned short port)
 						break;
 
 					if (!pattern || NULL != zbx_regexp_match(value, pattern, NULL)) {
-						send_err = send_value(
+						send_err = process_value(
 									server,
 									port,
 									CONFIG_HOSTNAME,
-									active_metrics[i].key,
+									active_metrics[i].key_orig,
 									value,
 									&lastlogsize,
 									&timestamp,
@@ -525,11 +783,11 @@ static void	process_active_checks(char *server, unsigned short port)
 					zabbix_log( LOG_LEVEL_WARNING, "Active check [%s] is not supported. Disabled.",
 						active_metrics[i].key);
 
-					send_err = send_value(
+					send_err = process_value(
 								server,
 								port,
 								CONFIG_HOSTNAME,
-								active_metrics[i].key,
+								active_metrics[i].key_orig,
 								"ZBX_NOTSUPPORTED",
 								&active_metrics[i].lastlogsize,
 								NULL,
@@ -551,11 +809,11 @@ static void	process_active_checks(char *server, unsigned short port)
 			{
 				zabbix_log( LOG_LEVEL_DEBUG, "For key [%s] received value [%s]", active_metrics[i].key, *pvalue);
 
-				send_err = send_value(
+				send_err = process_value(
 						server,
 						port,
 						CONFIG_HOSTNAME,
-						active_metrics[i].key,
+						active_metrics[i].key_orig,
 						*pvalue,
 						NULL,
 						NULL,
@@ -576,20 +834,6 @@ static void	process_active_checks(char *server, unsigned short port)
 	}
 }
 
-static void	refresh_metrics(char *server, unsigned short port)
-{
-	zabbix_log( LOG_LEVEL_DEBUG, "In refresh_metrics('%s',%u)",server, port);
-
-	while(get_active_checks(server, port) != SUCCEED)
-	{
-		zabbix_log( LOG_LEVEL_WARNING, "Getting list of active checks failed. Will retry after 60 seconds");
-
-		zbx_setproctitle("poller [sleeping for %d seconds]", 60);
-
-		zbx_sleep(60);
-	}
-}
-
 ZBX_THREAD_ENTRY(active_checks_thread, args)
 {
 	ZBX_THREAD_ACTIVECHK_ARGS activechk_args;
@@ -597,8 +841,7 @@ ZBX_THREAD_ENTRY(active_checks_thread, args)
 #if defined(ZABBIX_DAEMON)
 	struct	sigaction phan;
 #endif /* ZABBIX_DAEMON */
-	int	sleeptime, nextcheck;
-	int	nextrefresh;
+	int	nextcheck = 0, nextrefresh = 0, nextsend = 0;
 	char	*p = NULL;
 
 #if defined(ZABBIX_DAEMON)
@@ -618,42 +861,43 @@ ZBX_THREAD_ENTRY(active_checks_thread, args)
 
 	zabbix_log( LOG_LEVEL_INFORMATION, "zabbix_agentd active check started [%s:%u]", activechk_args.host, activechk_args.port);
 
-	zbx_setproctitle("getting list of active checks");
-
 	init_active_metrics();
 
-	refresh_metrics(activechk_args.host, activechk_args.port);
-	nextrefresh = (int)time(NULL) + CONFIG_REFRESH_ACTIVE_CHECKS;
-
 	while(ZBX_IS_RUNNING)
 	{
-		zbx_setproctitle("processing active checks");
-
-		process_active_checks(activechk_args.host, activechk_args.port);
-
-		nextcheck = get_min_nextcheck();
-		if (FAIL == nextcheck)
-			sleeptime = 60;
-		else {
-			sleeptime = nextcheck - (int)time(NULL);
-			sleeptime = MAX(sleeptime, 0);
+		if(time(NULL) >= nextsend)
+		{
+			send_buffer(activechk_args.host, activechk_args.port);
+			nextsend = (int)time(NULL) + 1;
 		}
 
-		if (sleeptime > 0) {
-			sleeptime = MIN(sleeptime, 60);
-
-			zabbix_log(LOG_LEVEL_DEBUG, "Sleeping for %d seconds", sleeptime );
-
-			zbx_setproctitle("poller [sleeping for %d seconds]", sleeptime);
-
-			zbx_sleep( sleeptime );
-		} else
-			zabbix_log(LOG_LEVEL_DEBUG, "No sleeping" );
-
 		if(time(NULL) >= nextrefresh)
 		{
-			refresh_metrics(activechk_args.host, activechk_args.port);
-			nextrefresh = (int)time(NULL) + CONFIG_REFRESH_ACTIVE_CHECKS;
+			zbx_setproctitle("poller [getting list of active checks]");
+
+			if(FAIL == refresh_active_checks(activechk_args.host, activechk_args.port))
+			{
+				nextrefresh = (int)time(NULL) + 60;
+			}
+			else
+			{
+				nextrefresh = (int)time(NULL) + CONFIG_REFRESH_ACTIVE_CHECKS;
+			}
+		}
+
+		if(time(NULL) >= nextcheck)
+		{
+			zbx_setproctitle("poller [processing active checks]");
+
+			process_active_checks(activechk_args.host, activechk_args.port);
+			nextcheck = get_min_nextcheck();
+			if(FAIL == nextcheck)	nextcheck = (int)time(NULL) + 60;
+		}
+		else
+		{
+			zabbix_log(LOG_LEVEL_DEBUG, "Sleeping for %d seconds", 1 );
+			zbx_setproctitle("poller [sleeping for %d seconds]", 1);
+			zbx_sleep(1);
 		}
 	}
 
