@@ -20,89 +20,11 @@
 #include "common.h"
 #include "cpustat.h"
 
-#include "log.h"
-
 #ifdef _WINDOWS
+	#include "log.h"
 	#include "perfmon.h"
 #endif /* _WINDOWS */
 
-/******************************************************************************
- *                                                                            *
- * Function: zbx_get_cpu_num                                                  *
- *                                                                            *
- * Purpose: returns the number of processors which are currently inline       *
- *          (i.e., available).                                                *
- *                                                                            *
- * Return value: number of CPUs                                               *
- *                                                                            *
- * Author: Eugene Grigorjev                                                   *
- *                                                                            *
- * Comments:                                                                  *
- *                                                                            *
- ******************************************************************************/
-static int	zbx_get_cpu_num(void)
-{
-#if defined(_WINDOWS)
-
-	SYSTEM_INFO	sysInfo;
-
-	GetSystemInfo(&sysInfo);
-
-	return (int)(sysInfo.dwNumberOfProcessors);
-
-#elif defined(HAVE_SYS_PSTAT_H)
-
-	struct pst_dynamic psd;
-
-	if ( -1 == pstat_getdynamic(&psd, sizeof(struct pst_dynamic), 1, 0) )
-	{
-		zabbix_log(LOG_LEVEL_WARNING , "Failed pstat_getdynamic to determine number of CPUs, adjust to 1");
-		return 1;
-	}
-	return (int)(psd.psd_proc_cnt);
-
-#elif defined(_SC_NPROCESSORS_ONLN)
-	int ncpu = 0;
-
-	if ( -1 == (ncpu = sysconf(_SC_NPROCESSORS_ONLN)) && EINVAL == errno )
-	{
-		zabbix_log(LOG_LEVEL_WARNING , "Failed sysconf to determine number of CPUs, adjust to 1");
-		return 1;
-	}
-
-	return ncpu;
-
-#elif defined(HAVE_PROC_CPUINFO)
-
-	FILE *f = NULL;
-	int ncpu = 0;
-
-	if(NULL == (file = fopen("/proc/cpuinfo","r") ))
-	{
-		zabbix_log(LOG_LEVEL_WARNING , "Cannot open [/proc/cpuinfo] to determine number of CPUs, adjust to 1 [%s]",strerror(errno));
-		return 1;
-	}
-
-	while(fgets(line,1024,file) != NULL)
-	{
-		if(strstr(line,"processor") == NULL) continue;
-		ncpu++;
-	}
-	zbx_fclose(file);
-
-	if ( ncpu <= 0 )
-	{
-		zabbix_log(LOG_LEVEL_DEBUG , "Can not find [processor] lines in [/proc/cpuinfo] to determine number of CPUs, adjust to 1");
-		return 1;
-	}
-
-	return ncpu;
-#else
-	zabbix_log(LOG_LEVEL_DEBUG , "Can not determine number of CPUs, adjust to 1");
-	return 1;
-#endif
-}
-
 /******************************************************************************
  *                                                                            *
  * Function: init_cpu_collector                                               *
@@ -125,49 +47,54 @@ static int	zbx_get_cpu_num(void)
 int	init_cpu_collector(ZBX_CPUS_STAT_DATA *pcpus)
 {
 #ifdef _WINDOWS
+	PDH_STATUS			status;
+	char				cpu[16], counter_path[PDH_MAX_COUNTER_PATH];
+	PDH_COUNTER_PATH_ELEMENTS	cpe;
+	int				i;
+	DWORD				dwSize;
 
-	PDH_STATUS	status;
-	int		i;
-	char		counter_path[MAX_COUNTER_PATH];
+	zabbix_log(LOG_LEVEL_DEBUG, "In init_cpu_collector()");
 
-	memset(pcpus, 0, sizeof(ZBX_CPUS_STAT_DATA));
-
-	pcpus->count = zbx_get_cpu_num();
-
-	if (PdhOpenQuery(NULL,0,&pcpus->pdh_query)!=ERROR_SUCCESS)
-	{
-		zabbix_log( LOG_LEVEL_ERR, "Call to PdhOpenQuery() failed: %s", strerror_from_system(GetLastError()));
+	if (ERROR_SUCCESS != (status = PdhOpenQuery(NULL, 0, &pcpus->pdh_query))) {
+		zabbix_log( LOG_LEVEL_ERR, "Call to PdhOpenQuery() failed: %s",
+				strerror_from_module(status, "PDH.DLL"));
 		return 1;
 	}
 
-	zbx_snprintf(counter_path, sizeof(counter_path), "\\%s(_Total)\\%s",GetCounterName(PCI_PROCESSOR),GetCounterName(PCI_PROCESSOR_TIME));
+	cpe.szMachineName = NULL;
+	cpe.szObjectName = GetCounterName(PCI_PROCESSOR);
+	cpe.szInstanceName = cpu;
+	cpe.szParentInstance = NULL;
+	cpe.dwInstanceIndex = -1;
+	cpe.szCounterName = GetCounterName(PCI_PROCESSOR_TIME);
 
-	if (ERROR_SUCCESS != (status = PdhAddCounter(
-		pcpus->pdh_query, 
-		counter_path, 0, 
-		&pcpus->cpu[0].usage_couter)))
-	{
-		zabbix_log( LOG_LEVEL_ERR, "Unable to add performance counter \"%s\" to query: %s", counter_path, strerror_from_module(status,"PDH.DLL"));
-		return 2;
-	}
+	for(i = 0 /* 0 : _Total; >0 : cpu */; i <= pcpus->count; i++) {
+		if (i == 0)
+			zbx_strlcpy(cpu, "_Total", sizeof(cpu));
+		else
+			_itoa_s(i - 1, cpu, sizeof(cpu), 10);
 
-	for(i=1 /* 0 - is Total cpus */; i <= pcpus->count /* "<=" instead of  "+ 1" */; i++)
-	{
-		zbx_snprintf(counter_path, sizeof(counter_path),"\\%s(%d)\\%s", GetCounterName(PCI_PROCESSOR), i-1, GetCounterName(PCI_PROCESSOR_TIME));
-
-		if (ERROR_SUCCESS != (status = PdhAddCounter(
-			pcpus->pdh_query, 
-			counter_path,0,
-			&pcpus->cpu[i].usage_couter)))
+		dwSize = sizeof(counter_path);
+		if (ERROR_SUCCESS != (status = PdhMakeCounterPath(&cpe, counter_path, &dwSize, 0)))
 		{
-			zabbix_log( LOG_LEVEL_ERR, "Unable to add performance counter \"%s\" to query: %s", counter_path, strerror_from_module(status,"PDH.DLL"));
+			zabbix_log(LOG_LEVEL_ERR, "Call to PdhMakeCounterPath() failed: %s",
+					strerror_from_module(status, "PDH.DLL"));
+			return 1;
+		}
+
+		if (ERROR_SUCCESS != (status = PdhAddCounter(pcpus->pdh_query, counter_path, 0,
+				&pcpus->cpu[i].usage_couter)))
+		{
+			zabbix_log( LOG_LEVEL_ERR, "Unable to add performance counter \"%s\" to query: %s",
+					counter_path, strerror_from_module(status, "PDH.DLL"));
 			return 2;
 		}
 	}
 
 	if (ERROR_SUCCESS != (status = PdhCollectQueryData(pcpus->pdh_query)))
 	{
-		zabbix_log( LOG_LEVEL_ERR, "Call to PdhCollectQueryData() failed: %s", strerror_from_module(status,"PDH.DLL"));
+		zabbix_log( LOG_LEVEL_ERR, "Call to PdhCollectQueryData() failed: %s",
+				strerror_from_module(status, "PDH.DLL"));
 		return 3;
 	}
 
@@ -176,31 +103,27 @@ int	init_cpu_collector(ZBX_CPUS_STAT_DATA *pcpus)
 		PdhGetRawCounterValue(pcpus->cpu[i].usage_couter, NULL, &pcpus->cpu[i].usage_old);
 	}
 
-	zbx_snprintf(counter_path, sizeof(counter_path), "\\%s\\%s", GetCounterName(PCI_SYSTEM), GetCounterName(PCI_PROCESSOR_QUEUE_LENGTH));
+	cpe.szObjectName = GetCounterName(PCI_SYSTEM);
+	cpe.szInstanceName = NULL;
+	cpe.szCounterName = GetCounterName(PCI_PROCESSOR_QUEUE_LENGTH);
+
+	dwSize = sizeof(counter_path);
+	if (ERROR_SUCCESS != (status = PdhMakeCounterPath(&cpe, counter_path, &dwSize, 0)))
+	{
+		zabbix_log(LOG_LEVEL_ERR, "Call to PdhMakeCounterPath() failed: %s",
+				strerror_from_module(status, "PDH.DLL"));
+		return 1;
+	}
 
 	/* Prepare for CPU execution queue usage collection */
 	if (ERROR_SUCCESS != (status = PdhAddCounter(pcpus->pdh_query, counter_path, 0, &pcpus->queue_counter)))
 	{
-		zabbix_log( LOG_LEVEL_ERR, "Unable to add performance counter \"%s\" to query: %s", counter_path, strerror_from_module(status,"PDH.DLL"));
+		zabbix_log( LOG_LEVEL_ERR, "Unable to add performance counter \"%s\" to query: %s",
+				counter_path, strerror_from_module(status, "PDH.DLL"));
 		return 2;
 	}
-
-#else /* not _WINDOWS */
-
-	memset(pcpus, 0, sizeof(ZBX_CPUS_STAT_DATA));
-
-	pcpus->count = zbx_get_cpu_num();
-
-
 #endif /* _WINDOWS */
 
-	if ( pcpus->count > MAX_CPU )
-	{
-		zabbix_log( LOG_LEVEL_DEBUG, "Not supported count of CPUs found %i, allowed %i", pcpus->count, MAX_CPU );
-		pcpus->count = MAX_CPU;
-	}
-
-
 	return 0;
 }
 
@@ -224,16 +147,17 @@ int	init_cpu_collector(ZBX_CPUS_STAT_DATA *pcpus)
 void	close_cpu_collector(ZBX_CPUS_STAT_DATA *pcpus)
 {
 #ifdef _WINDOWS
-
 	int i;
 
+	zabbix_log(LOG_LEVEL_DEBUG, "In close_cpu_collector()");
+
 	if(pcpus->queue_counter)
 	{
 		PdhRemoveCounter(pcpus->queue_counter);
 		pcpus->queue_counter = NULL;
 	}
 
-	for(i=0; i < MAX_CPU; i++)
+	for (i = 0; i < pcpus->count; i++)
 	{
 		if(pcpus->cpu[i].usage_couter)
 		{
@@ -247,9 +171,7 @@ void	close_cpu_collector(ZBX_CPUS_STAT_DATA *pcpus)
 		PdhCloseQuery(pcpus->pdh_query);
 		pcpus->pdh_query = NULL;
 	}
-
 #endif /* _WINDOWS */
-
 }
 
 #if !defined(_WINDOWS)
@@ -260,8 +182,8 @@ static int	get_cpustat(
 		zbx_uint64_t *cpu_user,
 		zbx_uint64_t *cpu_system,
 		zbx_uint64_t *cpu_nice,
-		zbx_uint64_t *cpu_idle
-
+		zbx_uint64_t *cpu_idle,
+		zbx_uint64_t *cpu_interrupt
 	)
 {
     #if defined(HAVE_PROC_STAT)
@@ -277,10 +199,17 @@ static int	get_cpustat(
 
     #elif defined(HAVE_FUNCTION_SYSCTLBYNAME)
 
-	static long	cp_time[5];
+	static long	cp_time[CPUSTATES];
 	size_t		nlen = sizeof(cp_time);
  	
-    #else /* not HAVE_FUNCTION_SYSCTLBYNAME */
+    #elif defined(HAVE_FUNCTION_SYSCTL_KERN_CPTIME)
+
+	int		mib[3];
+	long		all_states[CPUSTATES];
+	u_int64_t	one_states[CPUSTATES];
+	size_t		sz;
+	
+    #else /* not HAVE_FUNCTION_SYSCTL_KERN_CPTIME */
 
 	return 1;
 	
@@ -296,7 +225,8 @@ static int	get_cpustat(
 		return 1;
 	}
 
-	*cpu_user = *cpu_nice = *cpu_system = *cpu_idle = -1;
+	*cpu_user = *cpu_system = *cpu_nice = *cpu_idle = -1;
+	*cpu_interrupt	= 0;
 
 	zbx_snprintf(cpu_name, sizeof(cpu_name), "cpu%c ", cpuid > 0 ? '0' + (cpuid - 1) : ' ');
 
@@ -321,6 +251,7 @@ static int	get_cpustat(
 		*cpu_nice 	= (zbx_uint64_t)stats.psd_cpu_time[CP_NICE];
 		*cpu_system 	= (zbx_uint64_t)stats.psd_cpu_time[CP_SYS];
 		*cpu_idle 	= (zbx_uint64_t)stats.psd_cpu_time[CP_IDLE];
+		*cpu_interrupt	= 0;
 	}
 	else if( cpuid > 0 )
 	{
@@ -333,6 +264,7 @@ static int	get_cpustat(
 		*cpu_nice 	= (zbx_uint64_t)psp.psp_cpu_time[CP_NICE];
 		*cpu_system 	= (zbx_uint64_t)psp.psp_cpu_time[CP_SYS];
 		*cpu_idle 	= (zbx_uint64_t)psp.psp_cpu_time[CP_IDLE];
+		*cpu_interrupt	= 0;
 	}
 	else
 	{
@@ -340,19 +272,66 @@ static int	get_cpustat(
 	}
 
     #elif defined(HAVE_FUNCTION_SYSCTLBYNAME)
-	
+	/* FreeBSD 7.0 */
+
 	if (sysctlbyname("kern.cp_time", &cp_time, &nlen, NULL, 0) == -1)
 		return 1;
 
 	if (nlen != sizeof(cp_time))
 		return 1;
 
-	*cpu_user = (zbx_uint64_t)cp_time[0];
-	*cpu_nice = (zbx_uint64_t)cp_time[1];
-	*cpu_system = (zbx_uint64_t)cp_time[2];
-	*cpu_idle = (zbx_uint64_t)cp_time[4];
- 	
-    #endif /* HAVE_FUNCTION_SYSCTLBYNAME */
+	*cpu_user	= (zbx_uint64_t)cp_time[CP_USER];
+	*cpu_nice	= (zbx_uint64_t)cp_time[CP_NICE];
+	*cpu_system	= (zbx_uint64_t)cp_time[CP_SYS];
+	*cpu_interrupt	= (zbx_uint64_t)cp_time[CP_INTR];
+	*cpu_idle	= (zbx_uint64_t)cp_time[CP_IDLE];
+
+    #elif defined(HAVE_FUNCTION_SYSCTL_KERN_CPTIME)
+	/* OpenBSD 4.3 */
+
+	if (0 == cpuid)	/* all cpus */
+	{
+		mib[0] = CTL_KERN;
+		mib[1] = KERN_CPTIME;
+
+		sz = sizeof(all_states);
+		if (-1 == sysctl(mib, 2, &all_states, &sz, NULL, 0))
+			return 1;
+
+		if (sz != sizeof(all_states))
+			return 1;
+
+		*cpu_user	= (zbx_uint64_t)all_states[CP_USER];
+		*cpu_nice	= (zbx_uint64_t)all_states[CP_NICE];
+		*cpu_system	= (zbx_uint64_t)all_states[CP_SYS];
+		*cpu_interrupt	= (zbx_uint64_t)all_states[CP_INTR];
+		*cpu_idle	= (zbx_uint64_t)all_states[CP_IDLE];
+	}
+	else if (cpuid > 0)
+	{
+		mib[0] = CTL_KERN;
+		mib[1] = KERN_CPTIME2;
+		mib[2] = cpuid - 1;
+
+		sz = sizeof(one_states);
+		if (-1 == sysctl(mib, 3, &one_states, &sz, NULL, 0))
+			return 1;
+
+		if (sz != sizeof(one_states))
+			return 1;
+
+		*cpu_user	= (zbx_uint64_t)one_states[CP_USER];
+		*cpu_nice	= (zbx_uint64_t)one_states[CP_NICE];
+		*cpu_system	= (zbx_uint64_t)one_states[CP_SYS];
+		*cpu_interrupt	= (zbx_uint64_t)one_states[CP_INTR];
+		*cpu_idle	= (zbx_uint64_t)one_states[CP_IDLE];
+	}
+	else
+	{
+		return 1;
+	}
+
+    #endif /* HAVE_FUNCTION_SYSCTL_KERN_CPTIME */
 
 	return 0;
 }
@@ -365,82 +344,56 @@ static void	apply_cpustat(
 	zbx_uint64_t cpu_user, 
 	zbx_uint64_t cpu_system,
 	zbx_uint64_t cpu_nice,
-	zbx_uint64_t cpu_idle
+	zbx_uint64_t cpu_idle,
+	zbx_uint64_t cpu_interrupt
 	)
 {
 	register int	i	= 0;
 
-	int	time	= 0,
-		time1	= 0,
-		time5	= 0,
-		time15	= 0;
-
-	zbx_uint64_t
-		idle	= 0,
-		idle1	= 0,
-		idle5	= 0,
-		idle15	= 0,
-		user	= 0,
-		user1	= 0,
-		user5	= 0,
-		user15	= 0,
-		system	= 0,
-		system1	= 0,
-		system5	= 0,
-		system15= 0,
-		nice	= 0,
-		nice1	= 0,
-		nice5	= 0,
-		nice15	= 0,
-		all	= 0,
-		all1	= 0,
-		all5	= 0,
-		all15	= 0;
+	int		time = 0, time1 = 0, time5 = 0, time15 = 0;
+	zbx_uint64_t	user = 0, user1 = 0, user5 = 0, user15 = 0,
+			system = 0, system1 = 0, system5 = 0, system15 = 0,
+			nice = 0, nice1 = 0, nice5 = 0, nice15 = 0,
+			idle = 0, idle1 = 0, idle5 = 0, idle15 = 0,
+			interrupt = 0, interrupt1 = 0, interrupt5 = 0, interrupt15 = 0,
+			all = 0, all1 = 0, all5 = 0, all15 = 0;
 
 	ZBX_SINGLE_CPU_STAT_DATA
-		*curr_cpu = &pcpus->cpu[cpuid];
+			*curr_cpu = &pcpus->cpu[cpuid];
 
-
-	for(i=0; i < MAX_CPU_HISTORY; i++)
+	for (i = 0; i < MAX_CPU_HISTORY; i++)
 	{
-		if(curr_cpu->clock[i] < now - MAX_CPU_HISTORY)
-		{
-			curr_cpu->clock[i]	= now;
+		if (curr_cpu->clock[i] >= now - MAX_CPU_HISTORY)
+			continue;
 
-			user	= curr_cpu->h_user[i]	= cpu_user;
-			system	= curr_cpu->h_system[i]	= cpu_system;
-			nice	= curr_cpu->h_nice[i]	= cpu_nice;
-			idle	= curr_cpu->h_idle[i]	= cpu_idle;
+		curr_cpu->clock[i] = now;
+		curr_cpu->h_user[i] = user = cpu_user;
+		curr_cpu->h_system[i] = system = cpu_system;
+		curr_cpu->h_nice[i] = nice = cpu_nice;
+		curr_cpu->h_idle[i] = idle = cpu_idle;
+		curr_cpu->h_interrupt[i] = interrupt = cpu_interrupt;
 
-			all	= cpu_idle + cpu_user + cpu_nice + cpu_system;
-			break;
-		}
+		all = cpu_user + cpu_system + cpu_nice + cpu_idle + cpu_interrupt;
+		break;
 	}
 
-	time = time1 = time5 = time15 = now+1;
+	time = time1 = time5 = time15 = now + 1;
 
-	for(i=0; i < MAX_CPU_HISTORY; i++)
+	for (i = 0; i < MAX_CPU_HISTORY; i++)
 	{
-		if(0 == curr_cpu->clock[i])	continue;
+		if (0 == curr_cpu->clock[i])
+			continue;
 
-		if(curr_cpu->clock[i] == now)
-		{
-			idle	= curr_cpu->h_idle[i];
-			user	= curr_cpu->h_user[i];
-			nice	= curr_cpu->h_nice[i];
-			system	= curr_cpu->h_system[i];
-			all	= idle + user + nice + system;
-		}
-
-#define SAVE_CPU_CLOCK_FOR(t)										\
-		if((curr_cpu->clock[i] >= (now - (t * 60))) && (time ## t > curr_cpu->clock[i]))	\
-		{											\
-			time ## t	= curr_cpu->clock[i];						\
-			idle ## t	= curr_cpu->h_idle[i];						\
-			user ## t	= curr_cpu->h_user[i];						\
-			nice ## t	= curr_cpu->h_nice[i];						\
-			system ## t	= curr_cpu->h_system[i];					\
-			all ## t	= idle ## t + user ## t + nice ## t + system ## t;		\
+#define SAVE_CPU_CLOCK_FOR(t)											\
+		if ((curr_cpu->clock[i] >= (now - (t * 60))) && (time ## t > curr_cpu->clock[i]))		\
+		{												\
+			time ## t	= curr_cpu->clock[i];							\
+			user ## t	= curr_cpu->h_user[i];							\
+			system ## t	= curr_cpu->h_system[i];						\
+			nice ## t	= curr_cpu->h_nice[i];							\
+			idle ## t	= curr_cpu->h_idle[i];							\
+			interrupt ## t	= curr_cpu->h_interrupt[i];						\
+			all ## t	= user ## t + system ## t + nice ## t + idle ## t + interrupt ## t;	\
 		}
 
 		SAVE_CPU_CLOCK_FOR(1);
@@ -449,7 +402,7 @@ static void	apply_cpustat(
 	}
 
 #define CALC_CPU_LOAD(type, time)							\
-	if((type) - (type ## time) > 0 && (all) - (all ## time) > 0)			\
+	if ((type) - (type ## time) > 0 && (all) - (all ## time) > 0)			\
 	{										\
 		curr_cpu->type ## time = 100. * ((double)((type) - (type ## time)))/	\
 				((double)((all) - (all ## time)));			\
@@ -459,21 +412,25 @@ static void	apply_cpustat(
 		curr_cpu->type ## time = 0.;						\
 	}
 
-	CALC_CPU_LOAD(idle, 1);
-	CALC_CPU_LOAD(idle, 5);
-	CALC_CPU_LOAD(idle, 15);
-
 	CALC_CPU_LOAD(user, 1);
 	CALC_CPU_LOAD(user, 5);
 	CALC_CPU_LOAD(user, 15);
 
+	CALC_CPU_LOAD(system, 1);
+	CALC_CPU_LOAD(system, 5);
+	CALC_CPU_LOAD(system, 15);
+
 	CALC_CPU_LOAD(nice, 1);
 	CALC_CPU_LOAD(nice, 5);
 	CALC_CPU_LOAD(nice, 15);
 
-	CALC_CPU_LOAD(system, 1);
-	CALC_CPU_LOAD(system, 5);
-	CALC_CPU_LOAD(system, 15);
+	CALC_CPU_LOAD(idle, 1);
+	CALC_CPU_LOAD(idle, 5);
+	CALC_CPU_LOAD(idle, 15);
+
+	CALC_CPU_LOAD(interrupt, 1);
+	CALC_CPU_LOAD(interrupt, 5);
+	CALC_CPU_LOAD(interrupt, 15);
 }
 
 #endif /* not _WINDOWS */
@@ -482,16 +439,15 @@ void	collect_cpustat(ZBX_CPUS_STAT_DATA *pcpus)
 {
 #ifdef _WINDOWS
 
-	PDH_FMT_COUNTERVALUE 
-		value;
-	PDH_STATUS	
-		status;
-	LONG	sum;
-	int	i,
-		j,
-		n;
+	PDH_FMT_COUNTERVALUE	value;
+	PDH_STATUS		status;
+	LONG			sum;
+	int			i, j, n;
 
-	if(!pcpus->pdh_query) return;
+	if (!pcpus->pdh_query)
+		return;
+
+	zabbix_log(LOG_LEVEL_DEBUG, "In collect_cpustat()");
 
 	if ((status = PdhCollectQueryData(pcpus->pdh_query)) != ERROR_SUCCESS)
 	{
@@ -588,19 +544,20 @@ void	collect_cpustat(ZBX_CPUS_STAT_DATA *pcpus)
 		if (pcpus->h_queue_index == MAX_CPU_HISTORY)
 			pcpus->h_queue_index = 0;
 	}
+
 #else /* not _WINDOWS */
 
 	register int i = 0;
 	int	now = 0;
 
-	zbx_uint64_t cpu_user, cpu_nice, cpu_system, cpu_idle;
+	zbx_uint64_t cpu_user, cpu_nice, cpu_system, cpu_idle, cpu_interrupt;
 
 	for ( i = 0; i <= pcpus->count; i++ )
 	{
-		if(0 != get_cpustat(i, &now, &cpu_user, &cpu_system, &cpu_nice, &cpu_idle))
+		if(0 != get_cpustat(i, &now, &cpu_user, &cpu_system, &cpu_nice, &cpu_idle, &cpu_interrupt))
 			continue;
 
-		apply_cpustat(pcpus, i, now, cpu_user, cpu_system, cpu_nice, cpu_idle);
+		apply_cpustat(pcpus, i, now, cpu_user, cpu_system, cpu_nice, cpu_idle, cpu_interrupt);
 	}
 
 #endif /* _WINDOWS */
