@@ -20,44 +20,37 @@
 #ifndef ZABBIX_DISKDEVICES_H
 #define ZABBIX_DISKDEVICES_H
 
+#include "sysinfo.h"
 
 #define	MAX_DISKDEVICES	8
 
 typedef struct c_single_diskdevice_data
 {
-	char    *name;
-	int	major;
-	int	diskno;
-	int	clock[60*15];
-	double	read_io_ops[60*15];
-	double	blks_read[60*15];
-	double	write_io_ops[60*15];
-	double	blks_write[60*15];
+	char		name[32];
+	int		index;
+	time_t		clock[MAX_COLLECTOR_HISTORY];
+	zbx_uint64_t	r_oper[MAX_COLLECTOR_HISTORY];
+	zbx_uint64_t	r_sect[MAX_COLLECTOR_HISTORY];
+	zbx_uint64_t	w_oper[MAX_COLLECTOR_HISTORY];
+	zbx_uint64_t	w_sect[MAX_COLLECTOR_HISTORY];
+	zbx_uint64_t	r_ops[ZBX_AVGMAX];
+	zbx_uint64_t	r_sps[ZBX_AVGMAX];
+	zbx_uint64_t	r_bps[ZBX_AVGMAX];
+	zbx_uint64_t	w_ops[ZBX_AVGMAX];
+	zbx_uint64_t	w_sps[ZBX_AVGMAX];
+	zbx_uint64_t	w_bps[ZBX_AVGMAX];
 } ZBX_SINGLE_DISKDEVICE_DATA;
 
 typedef struct c_diskdevices_data
 {
-	ZBX_SINGLE_DISKDEVICE_DATA device[MAX_DISKDEVICES];
+	int				count;
+	ZBX_SINGLE_DISKDEVICE_DATA	device[MAX_DISKDEVICES];
 } ZBX_DISKDEVICES_DATA;
 
-void	collect_stats_diskdevices(ZBX_DISKDEVICES_DATA *pdiskdevices);
+#define DISKDEVICE_COLLECTOR_STARTED(collector) collector
 
-/*
-#define	MAX_DISKDEVICES	8
+ZBX_SINGLE_DISKDEVICE_DATA	*collector_diskdevice_get(const char *devname);
+ZBX_SINGLE_DISKDEVICE_DATA	*collector_diskdevice_add(const char *devname);
+void				collect_stats_diskdevices(ZBX_DISKDEVICES_DATA *pdiskdevices);
 
-#define DISKDEVICE struct diskdevice_type
-DISKDEVICE
-{
-	char    *device;
-	int	major;
-	int	diskno;
-	int	clock[60*15];
-	double	read_io_ops[60*15];
-	double	blks_read[60*15];
-	double	write_io_ops[60*15];
-	double	blks_write[60*15];
-};
-
-void	collect_stats_diskdevices(FILE *outfile);
-*/
 #endif
