@@ -50,6 +50,86 @@ ZBX_COLLECTOR_DATA *collector = NULL;
                 } 															\
         }}
 
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_get_cpu_num                                                  *
+ *                                                                            *
+ * Purpose: returns the number of processors which are currently inline       *
+ *          (i.e., available).                                                *
+ *                                                                            *
+ * Return value: number of CPUs                                               *
+ *                                                                            *
+ * Author: Eugene Grigorjev                                                   *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+static int	zbx_get_cpu_num(void)
+{
+#if defined(_WINDOWS)
+	SYSTEM_INFO	sysInfo;
+
+	GetSystemInfo(&sysInfo);
+
+	return (int)(sysInfo.dwNumberOfProcessors);
+#elif defined(HAVE_SYS_PSTAT_H)
+	struct pst_dynamic psd;
+
+	if (-1 == pstat_getdynamic(&psd, sizeof(struct pst_dynamic), 1, 0))
+		goto return_one;
+
+	return (int)(psd.psd_proc_cnt);
+return_one:
+#elif defined(_SC_NPROCESSORS_ONLN)
+	/* Solaris 10 x86 */
+	/* FreeBSD 7.0 x86 */
+	int	ncpu;
+
+	if (-1 == (ncpu = sysconf(_SC_NPROCESSORS_ONLN)))
+		goto return_one;
+
+	return ncpu;
+return_one:
+#elif defined(HAVE_FUNCTION_SYSCTL_HW_NCPU)
+	/* NetBSD 3.1 x86; NetBSD 4.0 x86 */
+	/* OpenBSD 4.2 x86 */
+	/* FreeBSD 6.2 x86; FreeBSD 7.0 x86 */
+	size_t	len;
+	int	mib[] = {CTL_HW, HW_NCPU}, ncpu;
+
+	len = sizeof(ncpu);
+
+	if (0 != sysctl(mib, 2, &ncpu, &len, NULL, 0))
+		goto return_one;
+
+	return ncpu;
+return_one:
+#elif defined(HAVE_PROC_CPUINFO)
+	FILE	*f = NULL;
+	int	ncpu = 0;
+
+	if (NULL == (file = fopen("/proc/cpuinfo", "r")))
+		goto return_one;
+
+	while (fgets(line, 1024, file) != NULL)
+	{
+		if (strstr(line, "processor") == NULL)
+			continue;
+		ncpu++;
+	}
+	zbx_fclose(file);
+
+	if (ncpu == 0)
+		goto return_one;
+
+	return ncpu;
+return_one:
+#endif
+
+	zabbix_log(LOG_LEVEL_WARNING, "Can not determine number of CPUs, adjust to 1");
+	return 1;
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: init_collector_data                                              *
@@ -68,24 +148,39 @@ ZBX_COLLECTOR_DATA *collector = NULL;
 
 void	init_collector_data(void)
 {
-#if defined (_WINDOWS)
+	int	cpu_count;
+	size_t	sz, sz_cpu;
+#ifndef _WINDOWS
+#define ZBX_MAX_ATTEMPTS 10
+	int	attempts = 0, shm_id;
+	key_t	shm_key;
+#endif
 
-	collector = zbx_malloc(collector, sizeof(ZBX_COLLECTOR_DATA));
+#if defined(_WINDOWS) || defined(HAVE_PROC_STAT) || defined(HAVE_SYS_PSTAT_H) || defined(HAVE_FUNCTION_SYSCTL_KERN_CPTIME)
+	cpu_count = zbx_get_cpu_num();
+#else /* HAVE_FUNCTION_SYSCTLBYNAME sysctlbyname("kern.cp_time"...) supported utilization of all CPU only */
+	cpu_count = 0;
+#endif
 
-	memset(collector, 0, sizeof(ZBX_COLLECTOR_DATA));
+	sz = sizeof(ZBX_COLLECTOR_DATA);
+	sz_cpu = sizeof(ZBX_SINGLE_CPU_STAT_DATA) * (cpu_count + 1);
+
+#ifdef _WINDOWS
+
+	collector = zbx_malloc(collector, sz + sz_cpu);
+	memset(collector, 0, sz + sz_cpu);
+
+	collector->cpus.cpu = (ZBX_SINGLE_CPU_STAT_DATA *)(collector + 1);
+	collector->cpus.count = cpu_count;
+
+	init_perf_collector(&collector->perfs);
 
 #else /* not _WINDOWS */
 
-#define ZBX_MAX_ATTEMPTS 10
-	int	attempts = 0;
-
-	key_t	shm_key;
-	int	shm_id;
-
 	ZBX_GET_SHM_KEY(shm_key);
 
 lbl_create:
-	if ( -1 == (shm_id = shmget(shm_key, sizeof(ZBX_COLLECTOR_DATA), IPC_CREAT | IPC_EXCL | 0666 /* 0022 */)) )
+	if ( -1 == (shm_id = shmget(shm_key, sz + sz_cpu, IPC_CREAT | IPC_EXCL | 0666 /* 0022 */)) )
 	{
 		if( EEXIST == errno )
 		{
@@ -114,6 +209,8 @@ lbl_create:
 	}
 	
 	collector = shmat(shm_id, 0, 0);
+	collector->cpus.cpu = (void *)collector + sz;
+	collector->cpus.count = cpu_count;
 
 	if ((void*)(-1) == collector)
 	{
@@ -190,18 +287,21 @@ void	free_collector_data(void)
 
 ZBX_THREAD_ENTRY(collector_thread, args)
 {
+	double	sec;
+
 	zabbix_log( LOG_LEVEL_INFORMATION, "zabbix_agentd collector started");
 
-	if ( init_cpu_collector(&(collector->cpus)) )
+	if (0 != init_cpu_collector(&(collector->cpus)))
 		close_cpu_collector(&(collector->cpus));
 
-	if( init_perf_collector(&(collector->perfs)) )
-		close_perf_collector(&(collector->perfs));
-
 	while(ZBX_IS_RUNNING)
 	{
-		collect_cpustat(&(collector->cpus));
-		collect_perfstat(&(collector->perfs));
+		sec = zbx_time();
+		if (CPU_COLLECTOR_STARTED(collector))
+			collect_cpustat(&(collector->cpus));
+#ifdef _WINDOWS
+		collect_perfstat();
+#endif /* _WINDOWS */
 
 		collect_stats_interfaces(&(collector->interfaces)); /* TODO */
 		collect_stats_diskdevices(&(collector->diskdevices)); /* TODO */
@@ -209,8 +309,11 @@ ZBX_THREAD_ENTRY(collector_thread, args)
 		zbx_sleep(1);
 	}
 
-	close_perf_collector(&(collector->perfs));
-	close_cpu_collector(&(collector->cpus));
+#ifdef _WINDOWS
+	close_perf_collector();
+#endif /* _WINDOWS */
+	if (CPU_COLLECTOR_STARTED(collector))
+		close_cpu_collector(&(collector->cpus));
 
 	zabbix_log( LOG_LEVEL_INFORMATION, "zabbix_agentd collector stopped");
 
