@@ -20,8 +20,14 @@
 #ifndef ZABBIX_DISCOVERER_H
 #define ZABBIX_DISCOVERER_H
 
+#include "common.h"
+
 extern	int	CONFIG_DISCOVERER_FORKS;
 
-void main_discoverer_loop(int num);
+void	register_host(DB_DHOST *dhost, const char *ip, int status);
+void	update_host_status(DB_DHOST *dhost, int status, int now);
+void	update_service(DB_DHOST *dhost, DB_DCHECK *check, char *ip, int port, int now);
+
+void	main_discoverer_loop(zbx_process_t p, int num);
 
 #endif
