@@ -40,6 +40,7 @@
 
 #include "poller/poller.h"
 #include "poller/checks_agent.h"
+#include "poller/checks_ipmi.h"
 
 /******************************************************************************
  *                                                                            *
@@ -58,7 +59,7 @@
  * Comments: Cannot use action->userid as it may also be groupid              *
  *                                                                            *
  ******************************************************************************/
-static	void	send_to_user_medias(DB_EVENT *event,DB_OPERATION *operation, zbx_uint64_t userid)
+/*static	void	send_to_user_medias(DB_EVENT *event,DB_OPERATION *operation, zbx_uint64_t userid)
 {
 	DB_MEDIA media;
 	DB_RESULT result;
@@ -95,13 +96,44 @@ static	void	send_to_user_medias(DB_EVENT *event,DB_OPERATION *operation, zbx_uin
 			continue;
 		}
 
-		DBadd_alert(operation->actionid, userid, event->objectid, media.mediatypeid,media.sendto,operation->shortdata,operation->longdata);
+		DBadd_alert(operation->actionid, userid, event->eventid, media.mediatypeid,media.sendto,operation->shortdata,operation->longdata);
 	}
 	DBfree_result(result);
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End send_to_user_medias()");
 }
+*/
+/******************************************************************************
+ *                                                                            *
+ * Function: check_user_active                                                *
+ *                                                                            *
+ * Purpose: checks if user in any users_disabled group                        *
+ *                                                                            *
+ * Parameters: userid - user id                                               *
+ *                                                                            *
+ * Return value: int SUCCEED / FAIL-if user disabled                          *
+ *                                                                            *
+ * Author: Aly                                                                *
+ *                                                                            *
+ * Comments:                    			                      *
+ *                                                                            *
+ ******************************************************************************/
+/*int check_user_active(zbx_uint64_t userid){
+	DB_RESULT	result;
+	DB_ROW		row;
+	int		rtrn = SUCCEED;
 
+	result = DBselect("SELECT COUNT(g.usrgrpid) FROM users_groups ug, usrgrp g WHERE ug.userid=" ZBX_FS_UI64 " AND g.usrgrpid=ug.usrgrpid AND g.users_status=%d", userid, GROUP_STATUS_DISABLED);
+	
+	row = DBfetch(result);
+	if(row && (DBis_null(row[0])!=SUCCEED) && (atoi(row[0])>0)) 
+		rtrn=FAIL;
+
+	DBfree_result(result);
+
+return rtrn;
+}
+*/
 /******************************************************************************
  *                                                                            *
  * Function: op_notify_user                                                   *
@@ -118,7 +150,7 @@ static	void	send_to_user_medias(DB_EVENT *event,DB_OPERATION *operation, zbx_uin
  * Comments: action->recipient specifies user or group                        *
  *                                                                            *
  ******************************************************************************/
-void	op_notify_user(DB_EVENT *event, DB_ACTION *action, DB_OPERATION *operation)
+/*void	op_notify_user(DB_EVENT *event, DB_ACTION *action, DB_OPERATION *operation)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
@@ -128,12 +160,15 @@ void	op_notify_user(DB_EVENT *event, DB_ACTION *action, DB_OPERATION *operation)
 
 	if(operation->object == OPERATION_OBJECT_USER)
 	{
-		send_to_user_medias(event, operation, operation->objectid);
+		if(check_user_active(operation->objectid) == SUCCEED)
+		{
+			send_to_user_medias(event, operation, operation->objectid);
+		}
 	}
 	else if(operation->object == OPERATION_OBJECT_GROUP)
 	{
-		result = DBselect("select u.userid from users u, users_groups ug where ug.usrgrpid=" ZBX_FS_UI64 " and ug.userid=u.userid",
-			operation->objectid);
+		result = DBselect("select u.userid from users u, users_groups ug, usrgrp g where ug.usrgrpid=" ZBX_FS_UI64 " and ug.userid=u.userid and g.usrgrpid=ug.usrgrpid and g.users_status=%d",
+			operation->objectid,GROUP_STATUS_ACTIVE);
 		while((row=DBfetch(result)))
 		{
 			ZBX_STR2UINT64(userid, row[0]);
@@ -152,7 +187,7 @@ void	op_notify_user(DB_EVENT *event, DB_ACTION *action, DB_OPERATION *operation)
 	}
 	zabbix_log(LOG_LEVEL_DEBUG, "End send_to_user()");
 }
-
+*/
 
 /******************************************************************************
  *                                                                            *
@@ -173,13 +208,17 @@ void	op_notify_user(DB_EVENT *event, DB_ACTION *action, DB_OPERATION *operation)
 
 static void run_remote_command(char* host_name, char* command)
 {
-	int ret = 9;
-	
+	int		ret = 9;
 	AGENT_RESULT	agent_result;
 	DB_ITEM         item;
 	DB_RESULT	result;
 	DB_ROW		row;
-	
+	char		*p, key[ITEM_KEY_LEN_MAX];
+#ifdef HAVE_OPENIPMI
+	int		val;
+	char		error[MAX_STRING_LEN];
+#endif
+
 	assert(host_name);
 	assert(command);
 
@@ -187,25 +226,51 @@ static void run_remote_command(char* host_name, char* command)
 		host_name,
 		command);
 
-	result = DBselect("select distinct host,ip,useip,port,dns from hosts where host='%s' and " ZBX_COND_NODEID,
+	result = DBselect("select distinct host,ip,useip,port,dns,useipmi,ipmi_port,ipmi_authtype,"
+			"ipmi_privilege,ipmi_username,ipmi_password from hosts where host='%s'" DB_NODE,
 			host_name,
-			LOCAL_NODE("hostid"));
-	row = DBfetch(result);
-	if(row)
-	{
-		item.host_name = row[0];
-		item.host_ip=row[1];
-		item.useip=atoi(row[2]);
-		item.port=atoi(row[3]);
-		item.host_dns=row[4];
-		
-		zbx_snprintf(item.key,ITEM_KEY_LEN_MAX,"system.run[%s,nowait]",command);
-		
-		alarm(CONFIG_TIMEOUT);
-		
-		ret = get_value_agent(&item, &agent_result);
+			DBnode_local("hostid"));
 
-		alarm(0);
+	if (NULL != (row = DBfetch(result)))
+	{
+		*key			= '\0';
+		item.key		= key;
+		item.host_name		= row[0];
+		item.host_ip		= row[1];
+		item.useip		= atoi(row[2]);
+		item.port		= atoi(row[3]);
+		item.host_dns		= row[4];
+
+		item.useipmi		= atoi(row[5]);
+		item.ipmi_port		= atoi(row[6]);
+		item.ipmi_authtype	= atoi(row[7]);
+		item.ipmi_privilege	= atoi(row[8]);
+		item.ipmi_username	= row[9];
+		item.ipmi_password	= row[10];
+
+		p = command;
+		while (*p == ' ' && *p != '\0')
+			p++;
+
+#ifdef HAVE_OPENIPMI
+		if (0 == strncmp(p, "IPMI", 4))
+		{
+			if (SUCCEED == (ret = parse_ipmi_command(p, &item.ipmi_sensor, &val)))
+				ret = set_ipmi_control_value(&item, val, error, sizeof(error));
+		}
+		else
+		{
+#endif
+			zbx_snprintf(key, sizeof(key), "system.run[%s,nowait]", p);
+
+			alarm(CONFIG_TIMEOUT);
+
+			ret = get_value_agent(&item, &agent_result);
+
+			alarm(0);
+#ifdef HAVE_OPENIPMI
+		}
+#endif
 	}
 	DBfree_result(result);
 	
@@ -320,44 +385,33 @@ static int get_next_command(char** command_list, char** alias, int* is_group, ch
  * Comments: commands devided with newline                                    *
  *                                                                            *
  ******************************************************************************/
-void	op_run_commands(DB_EVENT *event, DB_OPERATION *operation)
+void	op_run_commands(char *cmd_list)
 {
-	DB_RESULT result;
+	DB_RESULT	result;
 	DB_ROW		row;
+	char		*alias, *command;
+	int		is_group;
 
-	char *cmd_list = NULL;
-	char *alias = NULL;
-	char *command = NULL;
-	int is_group = 0;
+	assert(cmd_list);
 
-	assert(event);
-	assert(operation);
+	zabbix_log(LOG_LEVEL_DEBUG, "In run_commands()");
 
-	zabbix_log( LOG_LEVEL_DEBUG, "In run_commands(operationid:" ZBX_FS_UI64 ")",
-		operation->operationid);
+	while (1 != get_next_command(&cmd_list, &alias, &is_group, &command)) {
+		if (!alias || *alias == '\0' || !command || *command == '\0')
+			continue;
 
-	cmd_list = operation->longdata;
-	while(get_next_command(&cmd_list,&alias,&is_group,&command)!=1)
-	{
-		if(!alias || !command) continue;
-		if(alias == '\0' || command == '\0') continue;
-		if(is_group)
-		{
-			result = DBselect("select distinct h.host from hosts_groups hg,hosts h, groups g where hg.hostid=h.hostid and hg.groupid=g.groupid and g.name='%s' and" ZBX_COND_NODEID,
-				alias,
-				LOCAL_NODE("h.hostid"));
-			while((row=DBfetch(result)))
-			{
+		if (is_group) {
+			result = DBselect("select distinct h.host from hosts_groups hg,hosts h,groups g"
+					" where hg.hostid=h.hostid and hg.groupid=g.groupid and g.name='%s'" DB_NODE,
+					alias,
+					DBnode_local("h.hostid"));
+
+			while (NULL != (row = DBfetch(result)))
 				run_remote_command(row[0], command);
-			}
-			
+
 			DBfree_result(result);
-		}
-		else
-		{
+		} else
 			run_remote_command(alias, command);
-		}
-/*		DBadd_alert(action->actionid,trigger->triggerid, userid, media.mediatypeid,media.sendto,action->subject,action->scripts); */ /* TODO !!! Add alert for remote commands !!! */
 	}
 	zabbix_log( LOG_LEVEL_DEBUG, "End run_commands()");
 }
@@ -459,19 +513,20 @@ static zbx_uint64_t	add_discovered_host(zbx_uint64_t dhostid)
 	DB_RESULT	result2;
 	DB_ROW		row;
 	DB_ROW		row2;
-	zbx_uint64_t	hostid = 0;
+	zbx_uint64_t	hostid = 0, proxy_hostid;
 	char		*ip;
 	char		host[MAX_STRING_LEN], host_esc[MAX_STRING_LEN];
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In add_discovered_host(dhostid:" ZBX_FS_UI64 ")",
-		dhostid);
+			dhostid);
 
-	result = DBselect("select ip from dhosts where dhostid=" ZBX_FS_UI64,
-		dhostid);
-	row = DBfetch(result);
-	if(row && DBis_null(row[0]) != SUCCEED)
-	{
-		ip=row[0];
+	result = DBselect("select dr.proxy_hostid,dh.ip from dhosts dh, drules dr"
+			" where dr.druleid=dh.druleid and dh.dhostid=" ZBX_FS_UI64,
+			dhostid);
+
+	if (NULL != (row = DBfetch(result)) && DBis_null(row[1]) != SUCCEED) {
+		proxy_hostid = zbx_atoui64(row[0]);
+		ip = row[1];
 
 		alarm(CONFIG_TIMEOUT);
 		zbx_gethost_by_ip(ip, host, sizeof(host));
@@ -479,24 +534,22 @@ static zbx_uint64_t	add_discovered_host(zbx_uint64_t dhostid)
 
 		DBescape_string(host, host_esc, sizeof(host_esc));
 
-		result2 = DBselect("select hostid from hosts where ip='%s' and " ZBX_COND_NODEID,
-			ip,
-			LOCAL_NODE("hostid"));
-		row2 = DBfetch(result2);
-		if(!row2 || DBis_null(row2[0]) == SUCCEED)
-		{
-			hostid = DBget_maxid("hosts","hostid");
-			DBexecute("insert into hosts (hostid,host,useip,ip,dns) values (" ZBX_FS_UI64 ",'%s',1,'%s','%s')",
-				hostid,
-				(host[0] != '\0' ? host_esc : ip), /* Use host name if exists, IP otherwise */
+		result2 = DBselect("select hostid from hosts where ip='%s'" DB_NODE,
 				ip,
-				host_esc);
-		}
-		else
-		{
+				DBnode_local("hostid"));
+
+		if (NULL == (row2 = DBfetch(result2)) || DBis_null(row2[0]) == SUCCEED) {
+			hostid = DBget_maxid("hosts","hostid");
+			DBexecute("insert into hosts (hostid,proxy_hostid,host,useip,ip,dns)"
+					" values (" ZBX_FS_UI64 "," ZBX_FS_UI64 ",'%s',1,'%s','%s')",
+					hostid,
+					proxy_hostid,
+					(host[0] != '\0' ? host_esc : ip), /* Use host name if exists, IP otherwise */
+					ip,
+					host_esc);
+		} else {
 			ZBX_STR2UINT64(hostid, row2[0]);
-			if(host_esc[0] != '\0')
-			{
+			if (host_esc[0] != '\0') {
 				DBexecute("update hosts set dns='%s' where hostid=" ZBX_FS_UI64,
 					host_esc,
 					hostid);
