@@ -20,15 +20,11 @@
 #ifndef ZABBIX_PINGER_H
 #define ZABBIX_PINGER_H
 
+#include "common.h"
+
 extern	int	CONFIG_PINGER_FORKS;
 extern	int	CONFIG_PINGER_FREQUENCY;
-extern	char	*CONFIG_FPING_LOCATION;
-#ifdef HAVE_IPV6
-extern	char	*CONFIG_FPING6_LOCATION;
-#endif /* HAVE_IPV6 */
 
-extern	void	signal_handler( int sig );
-
-void main_pinger_loop(int num);
+void	main_pinger_loop(zbx_process_t p, int num);
 
 #endif
