@@ -18,6 +18,7 @@
 **/
 #include "common.h"
 #include "comms.h"
+#include "log.h"
 
 #include "checks_agent.h"
 
@@ -60,15 +61,13 @@ int	get_value_agent(DB_ITEM *item, AGENT_RESULT *result)
 			addr,
 			item->key);
 
-	if (SUCCEED == (ret = zbx_tcp_connect(&s, addr, item->port, 0))) {
+	if (SUCCEED == (ret = zbx_tcp_connect(&s, CONFIG_SOURCE_IP, addr, item->port, 0))) {
 		zbx_snprintf(packet, sizeof(packet), "%s\n",item->key);
 		zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]", packet);
 
 		/* Send requests using old protocol */
 		if( SUCCEED == (ret = zbx_tcp_send_raw(&s, packet)) )
 		{
-			zabbix_log(LOG_LEVEL_DEBUG, "Before read");
-
 			ret = zbx_tcp_recv_ext(&s, &buf, ZBX_TCP_READ_UNTIL_CLOSE);
 		}
 	}
