@@ -41,8 +41,8 @@
 #include "log.h"
 #include "zlog.h"
 
-#include "dbsync.h"
 #include "nodesync.h"
+#include "../nodewatcher/nodesender.h"
 
 /******************************************************************************
  *                                                                            *
@@ -60,19 +60,20 @@
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int	process_record(int nodeid, char *record)
+static int	process_record(int nodeid, const char *record, int sender_nodetype)
 {
 	char		tablename[MAX_STRING_LEN];
 	char		fieldname[MAX_STRING_LEN];
 	zbx_uint64_t	recid;
-	int		op;
+	int		op, res = SUCCEED;
 	int		valuetype;
 	char		value_esc[MAX_STRING_LEN];
 	int		i;
 	char		*key=NULL;
 	DB_RESULT	result;
 	DB_ROW		row;
-	char		*r, *buffer = NULL, *tmp = NULL, *fields_update = NULL, *fields = NULL, *values = NULL;
+	const char	*r;
+	char		*buffer = NULL, *tmp = NULL, *fields_update = NULL, *fields = NULL, *values = NULL;
 	int		buffer_allocated = 16*1024;
 	int		tmp_allocated = 16*1024, tmp_offset = 0;
 	int		fields_update_allocated = 16*1024, fields_update_offset = 0;
@@ -87,17 +88,14 @@ static int	process_record(int nodeid, char *record)
 	r = record;
 	buffer = zbx_malloc(buffer, buffer_allocated);
 	tmp = zbx_malloc(tmp, tmp_allocated);
-	fields_update = zbx_malloc(fields_update, fields_update_allocated);
-	fields = zbx_malloc(fields, fields_allocated);
-	values = zbx_malloc(values, values_allocated);
 
-	r = zbx_get_next_field(r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
-	strcpy(tablename, buffer);
+	zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
+	zbx_strlcpy(tablename, buffer, sizeof(tablename));
 
-	r = zbx_get_next_field(r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
-	sscanf(buffer, ZBX_FS_UI64,&recid);
+	zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
+	ZBX_STR2UINT64(recid, buffer);
 
-	r = zbx_get_next_field(r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
+	zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
 	op = atoi(buffer);
 
 	for(i=0;tables[i].table!=0;i++)
@@ -113,68 +111,76 @@ static int	process_record(int nodeid, char *record)
 	{
 		zabbix_log( LOG_LEVEL_WARNING, "Cannot find key field for table [%s]",
 			tablename);
-		return FAIL;
+		res = FAIL;
+		goto out;
 	}
 	if(op==NODE_CONFIGLOG_OP_DELETE)
 	{
-		zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 16*1024, "delete from %s where %s=" ZBX_FS_UI64,
+		zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 256, "delete from %s where %s="ZBX_FS_UI64,
 			tablename,
 			key,
 			recid);
 		DBexecute("%s", tmp);
-		return SUCCEED;
+		goto out;
 	}
 
+	fields_update = zbx_malloc(fields_update, fields_update_allocated);
+	fields = zbx_malloc(fields, fields_allocated);
+	values = zbx_malloc(values, values_allocated);
+
+	zbx_snprintf_alloc(&fields, &fields_allocated, &fields_offset, 128, "%s,", key);
+	zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 128, ZBX_FS_UI64",", recid);
+
 	while(r != NULL)
 	{
-		r = zbx_get_next_field(r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
-		strcpy(fieldname, buffer);
+		zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
+		zbx_strlcpy(fieldname, buffer, sizeof(fieldname));
 
-		r = zbx_get_next_field(r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
+		zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
 		valuetype=atoi(buffer);
 
-		r = zbx_get_next_field(r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
-		if(op==NODE_CONFIGLOG_OP_UPDATE || op==NODE_CONFIGLOG_OP_ADD)
+		zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
+		if(op==NODE_CONFIGLOG_OP_UPDATE)
 		{
 			if(strcmp(buffer, "NULL") == 0)
 			{
-				zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 16*1024, "%s=NULL,",
+				zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 128, "%s=NULL,",
 					fieldname);
-				zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 16*1024, "NULL,");
+				zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 128, "NULL,");
 			}
 			else
 			{
 				if(valuetype == ZBX_TYPE_INT || valuetype == ZBX_TYPE_UINT || valuetype == ZBX_TYPE_ID || valuetype == ZBX_TYPE_FLOAT)
 				{
-					zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 16*1024, "%s=%s,",
+					zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 256, "%s=%s,",
 						fieldname,
 						buffer);
-					zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 16*1024, "%s,",
+					zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 128, "%s,",
 						buffer);
 				}
 				else if(valuetype == ZBX_TYPE_BLOB)
 				{
 					if(*buffer == '\0')
 					{
-						zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 16*1024, "%s='',",
+						zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 128, "%s='',",
 							fieldname);
-						zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 16*1024, "'',");
+						zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 128, "'',");
 					}
 					else
 					{
 #if defined(HAVE_POSTGRESQL)
 						len = zbx_hex2binary(buffer);
 						zbx_pg_escape_bytea((u_char *)buffer, len, &tmp, &tmp_allocated);
-						zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 16*1024, "%s='%s',",
+						zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, strlen(tmp)+256, "%s='%s',",
 							fieldname,
 							tmp);
-						zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 16*1024, "'%s',",
+						zbx_snprintf_alloc(&values, &values_allocated, &values_offset, strlen(tmp)+256, "'%s',",
 							tmp);
 #else
-						zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 16*1024, "%s=0x%s,",
+						zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, strlen(buffer)+256, "%s=0x%s,",
 							fieldname,
 							buffer);
-						zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 16*1024, "0x%s,",
+						zbx_snprintf_alloc(&values, &values_allocated, &values_offset, strlen(buffer)+256, "0x%s,",
 							buffer);
 #endif
 					}
@@ -184,21 +190,22 @@ static int	process_record(int nodeid, char *record)
 					zbx_hex2binary(buffer);
 					DBescape_string(buffer, value_esc,MAX_STRING_LEN);
 
-					zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 16*1024, "%s='%s',",
+					zbx_snprintf_alloc(&fields_update, &fields_update_allocated, &fields_update_offset, 256, "%s='%s',",
 						fieldname,
 						value_esc);
-					zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 16*1024, "'%s',",
+					zbx_snprintf_alloc(&values, &values_allocated, &values_offset, 256, "'%s',",
 						value_esc);
 				}
 			}
 
-			zbx_snprintf_alloc(&fields, &fields_allocated, &fields_offset, 4*1024, "%s,", fieldname);
+			zbx_snprintf_alloc(&fields, &fields_allocated, &fields_offset, 128, "%s,", fieldname);
 		}
 		else
 		{
 			zabbix_log( LOG_LEVEL_WARNING, "Unknown record operation [%d]",
 				op);
-			return FAIL;
+			res = FAIL;
+			goto out;
 		}
 	}
 	if(fields_offset != 0)		fields[fields_offset - 1]='\0';
@@ -207,16 +214,7 @@ static int	process_record(int nodeid, char *record)
 
 	if(op==NODE_CONFIGLOG_OP_UPDATE)
 	{
-		zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 16*1024, "update %s set %s where %s=" ZBX_FS_UI64,
-			tablename,
-			fields_update,
-			key,
-			recid);
-/*zabbix_log( LOG_LEVEL_WARNING, "----- process_record() [5] [tmp_allocated:%d] [tmp_offset:%d] [tmp:%s]", tmp_allocated, tmp_offset, tmp);*/
-	}
-	else if(op==NODE_CONFIGLOG_OP_ADD)
-	{
-		result = DBselect("select 0 from %s where %s=" ZBX_FS_UI64,
+		result = DBselect("select 0 from %s where %s="ZBX_FS_UI64,
 			tablename,
 			key,
 			recid);
@@ -238,20 +236,29 @@ static int	process_record(int nodeid, char *record)
 		}
 		DBfree_result(result);
 	}
-/*	zabbix_log( LOG_LEVEL_WARNING, "SQL [%s]", tmp);*/
-	if(FAIL == DBexecute("%s",tmp))
-	{
-		zabbix_log( LOG_LEVEL_WARNING, "Failed [%s]",
-			record);
+	DBexecute("%s",tmp);
+
+	if (FAIL == calculate_checksums(nodeid, tablename, recid) ||
+		FAIL == update_checksums(nodeid, sender_nodetype, SUCCEED, tablename, recid, fields) ) {
+		res = FAIL;
+		goto out;
 	}
+/*	zabbix_log( LOG_LEVEL_CRIT, "RECORD [%s]", record);*/
+/*	zabbix_log( LOG_LEVEL_CRIT, "SQL [%s] %s", tmp, res == FAIL ? "FAIL" : "SUCCEED");*/
 
-	zbx_free(buffer);
-	zbx_free(tmp);
-	zbx_free(fields_update);
-	zbx_free(fields);
-	zbx_free(values);
+out:
+	if (NULL != buffer)
+		zbx_free(buffer);
+	if (NULL != tmp)
+		zbx_free(tmp);
+	if (NULL != fields_update)
+		zbx_free(fields_update);
+	if (NULL != fields)
+		zbx_free(fields);
+	if (NULL != values)
+		zbx_free(values);
 
-	return SUCCEED;
+	return res;
 }
 /******************************************************************************
  *                                                                            *
@@ -269,66 +276,63 @@ static int	process_record(int nodeid, char *record)
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-int	node_sync(char *data)
+int	node_sync(char *data, int *sender_nodeid, int *nodeid)
 {
-	char	*start, *newline = NULL, *tmp = NULL;
-	int	tmp_allocated = 128;
-	int	firstline=1;
-	int	nodeid=0;
-	int	sender_nodeid=0;
-	int	datalen;
+	const char	*r;
+	char		*newline, *tmp = NULL;
+	int		tmp_allocated = 128;
+	int		firstline=1;
+	int		sender_nodetype=0;
+	int		datalen;
+	int		res = SUCCEED;
 
 	datalen=strlen(data);
 
 	zabbix_log( LOG_LEVEL_DEBUG, "In node_sync(len:%d)", datalen);
 
-	DBbegin();
-
 	tmp = zbx_malloc(tmp, tmp_allocated);
 
-	for(start = data; *start != '\0';)
-	{
-		if(NULL != (newline = strchr(start, '\n')))
-		{
+/*zabbix_log(LOG_LEVEL_CRIT, "<----- [%s]", data);*/
+
+	for (r = data; *r != '\0' && res == SUCCEED;) {
+		if (NULL != (newline = strchr(r, '\n')))
 			*newline = '\0';
-		}
 
-		if(firstline == 1)
-		{
-/*			zabbix_log( LOG_LEVEL_DEBUG, "First line [%s]", start);*/ 
-			start = zbx_get_next_field(start, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* Data */
-			start = zbx_get_next_field(start, &tmp, &tmp_allocated, ZBX_DM_DELIMITER);
-			sender_nodeid=atoi(tmp);
-			start = zbx_get_next_field(start, &tmp, &tmp_allocated, ZBX_DM_DELIMITER);
-			nodeid=atoi(tmp);
+		if (firstline == 1) {
+			zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* Data */
+			zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER);
+			*sender_nodeid=atoi(tmp);
+			sender_nodetype = *sender_nodeid == CONFIG_MASTER_NODEID ? ZBX_NODE_MASTER : ZBX_NODE_SLAVE;
+			zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER);
+			*nodeid=atoi(tmp);
 
-			firstline=0;
-			zabbix_log( LOG_LEVEL_WARNING, "NODE %d: Received data from node %d for node %d datalen %d",
+			if (0 != *sender_nodeid && 0 != *nodeid) {
+				zabbix_log( LOG_LEVEL_WARNING, "NODE %d: Received data from %s node %d for node %d datalen %d",
 					CONFIG_NODEID,
-					sender_nodeid,
-					nodeid,
+					sender_nodetype == ZBX_NODE_SLAVE ? "slave" : "master",
+					*sender_nodeid,
+					*nodeid,
 					datalen);
-		}
-		else
-		{
-/*			zabbix_log( LOG_LEVEL_DEBUG, "Got line [%s]", start);*/
-			process_record(nodeid, start);
-		}
 
-		if(newline != NULL)
-		{
+/*				DBbegin();*/
+
+				DBexecute("delete from node_cksum where nodeid=%d and cksumtype=%d",
+					*nodeid,
+					NODE_CKSUM_TYPE_NEW);
+
+				firstline=0;
+			} else
+				res = FAIL;
+		} else
+			res = process_record(*nodeid, r, sender_nodetype);
+
+		if (newline != NULL) {
 			*newline = '\n';
-			start = newline + 1;
-			newline = NULL;
-		}
-		else
-		{
+			r = newline + 1;
+		} else
 			break;
-		}
 	}
 	zbx_free(tmp);
 
-	DBcommit();
-
-	return SUCCEED;
+	return res;
 }
