@@ -20,12 +20,24 @@
 #ifndef ZABBIX_TRAPPER_H
 #define ZABBIX_TRAPPER_H
 
-extern	int	server_num;
+#include "common.h"
+#include "comms.h"
 
-extern	int	CONFIG_TIMEOUT;
+#define AGENT_VALUE	struct zbx_agent_value_t
 
-extern	void	signal_handler( int sig );
+AGENT_VALUE
+{
+	int	clock;
+	char	host_name[HOST_HOST_LEN_MAX];
+	char	key[ITEM_KEY_LEN_MAX];
+	char	*value;
+	int	lastlogsize;
+	int	timestamp;
+	char	*source;
+	int	severity;
+};
 
-void	child_trapper_main(int i, zbx_sock_t *s);
+int	send_result(zbx_sock_t *sock, int result, char *info);
+void	child_trapper_main(zbx_process_t p, zbx_sock_t *s);
 
 #endif
